(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    253202,       7032]
NotebookOptionsPosition[    243455,       6720]
NotebookOutlinePosition[    244325,       6754]
CellTagsIndexPosition[    244206,       6747]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
THE VIX\[RegisteredTrademark] CALCULATION STEP-BY-STEP\
\>", "Title",
 CellChangeTimes->{3.469301368344406*^9, 3.46944614167655*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DateString", "[", "]"}]], "Input",
 CellChangeTimes->{{3.470139202482369*^9, 3.470139204779861*^9}}],

Cell[BoxData["\<\"Fri 18 Dec 2009 09:33:25\"\>"], "Output",
 CellChangeTimes->{3.470139205715457*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Introduction", "Section",
 CellChangeTimes->{{3.470139187795977*^9, 3.4701391896102657`*^9}}],

Cell[TextData[{
 "The Chicago Board Options Exchange\[RegisteredTrademark] (CBOE\
\[RegisteredTrademark]) Volatility Index\[RegisteredTrademark], also known as \
the VIX\[RegisteredTrademark], is a benchmark for U.S. stock market \
volatility. The VIX\[RegisteredTrademark] is based on the S&P 500\
\[RegisteredTrademark] Index, and estimates expected volatility by averaging \
the weighted prices of SPX puts and calls over a wide range of strike prices. \
The CBOE\[RegisteredTrademark] has a whitepaper describing a step by step \
calculation of the VIX\[RegisteredTrademark]: the ",
 ButtonBox["http://www.cboe.com/micro/vix/vixwhite.pdf",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.cboe.com/micro/vix/vixwhite.pdf"], None},
  ButtonNote->"http://www.cboe.com/micro/vix/vixwhite.pdf"],
 ".\nThe purpose of this notebook is to demonstrate how to implement the VIX\
\[RegisteredTrademark] calculation using ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " by following the step by step implementation outlined in the CBOE\
\[RegisteredTrademark] white paper. Ideally the notebook would be read \
alongside the CBOE\[RegisteredTrademark] white paper. Remarks from the CBOE\
\[RegisteredTrademark] white paper are shown in italics."
}], "Text",
 CellChangeTimes->{{3.469446077564642*^9, 3.469446126155384*^9}, {
  3.469449307570284*^9, 3.469449391358704*^9}, {3.469449459739196*^9, 
  3.4694494944754057`*^9}, {3.469449649896843*^9, 3.4694496793688107`*^9}, {
  3.469450991668569*^9, 3.469451072985135*^9}, {3.470138934698386*^9, 
  3.470138991065195*^9}}],

Cell["\<\
The generalized VIX\[RegisteredTrademark] formula, given in the CBOE\
\[RegisteredTrademark] white paper, is:\
\>", "Text",
 CellChangeTimes->{{3.4693701045600243`*^9, 3.46937017971208*^9}, {
  3.469451364386571*^9, 3.4694514024374943`*^9}, {3.469451434799226*^9, 
  3.46945143666019*^9}, {3.469451854616961*^9, 3.4694518552455587`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Sigma]", "2"], "=", 
   RowBox[{
    RowBox[{
     FractionBox["2", "T"], 
     RowBox[{
      UnderscriptBox["\[Sum]", "i"], 
      RowBox[{
       FractionBox[
        RowBox[{"\:2206", "\[VeryThinSpace]", 
         SubscriptBox["K", "i"]}], 
        RowBox[{"\[VeryThinSpace]", 
         SuperscriptBox[
          SubscriptBox["K", "i"], "2"]}]], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"R", "\[VeryThinSpace]", "T"}]], 
       RowBox[{"Q", "(", 
        SubscriptBox["K", "i"], ")"}]}]}]}], "-", 
    RowBox[{
     FractionBox["1", "T"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        FractionBox["F", 
         SubscriptBox["K", "0"]], "-", "1"}], ")"}], "2"]}]}]}], 
  TraditionalForm]], "DisplayFormulaNumbered",
 CellChangeTimes->{{3.469369943748357*^9, 3.469370096762732*^9}, {
  3.469451342663644*^9, 3.4694513618054323`*^9}, {3.4694514435516453`*^9, 
  3.469451477229848*^9}},
 TextAlignment->Center,
 TextJustification->0.,
 CellTags->"eqn1"],

Cell[TextData[{
 Cell[BoxData[
  FormBox["T", TraditionalForm]]],
 "\tTime to expiration\n",
 Cell[BoxData[
  FormBox["F", TraditionalForm]]],
 "\tForward index level derived from index option prices\n",
 Cell[BoxData[
  FormBox[
   SubscriptBox["K", "0"], TraditionalForm]]],
 "\tFirst strike below the forward index level, F\n",
 Cell[BoxData[
  FormBox[
   SubscriptBox["K", "i"], TraditionalForm]]],
 "\tStrike price of ith out-of-the-money option; a call if Ki>K0 and a put if \
Ki< K0; both put and call if Ki=K0.\n",
 Cell[BoxData[
  FormBox[
   RowBox[{"\:2206", "\[VeryThinSpace]", 
    SubscriptBox["K", "i"]}], TraditionalForm]],
  CellChangeTimes->{{3.469369943748357*^9, 3.469370096762732*^9}, {
   3.469451342663644*^9, 3.4694513618054323`*^9}, {3.4694514435516453`*^9, 
   3.469451477229848*^9}}],
 "\tInterval between strike prices \[Dash] half the difference between the \
strike on either side of Ki:"
}], "Text",
 CellChangeTimes->{
  3.469451529959469*^9, {3.469451570947974*^9, 3.469451741421404*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\:2206", "\[VeryThinSpace]", 
    SubscriptBox["K", "i"]}], "=", 
   FractionBox[
    RowBox[{
     SubscriptBox["K", 
      RowBox[{"i", "+", "1"}]], " ", "\[Minus]", 
     SubscriptBox["K", 
      RowBox[{"i", "-", "1"}]]}], "2"]}], 
  TraditionalForm]], "DisplayFormulaNumbered",
 CellChangeTimes->{{3.46945174944506*^9, 3.469451800549082*^9}},
 TextAlignment->Center,
 TextJustification->0.,
 CellTags->"eqn2"],

Cell[TextData[{
 Cell[BoxData[
  FormBox["R", TraditionalForm]],
  FormatType->"TraditionalForm"],
 "\tRisk-free interest rate to expiration\n",
 Cell[BoxData[
  FormBox[
   RowBox[{"Q", "(", 
    SubscriptBox["K", "i"], ")"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "\tThe midpoint of the bid-ask spread for each option with strike Ki.\n "
}], "Text",
 CellChangeTimes->{
  3.469451529959469*^9, {3.469451570947974*^9, 3.469451751643549*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Handling date and time", "Section",
 CellChangeTimes->{{3.469281141175273*^9, 3.469281147045286*^9}}],

Cell[TextData[{
 "\[OpenCurlyDoubleQuote]",
 StyleBox["In this hypothetical example, the near-term and next-term options \
have 9 days and 37 days to expiration, respectively, and reflect prices \
observed at the open of trading \[Dash] 8:30 a.m.",
  FontSlant->"Italic"],
 "\[CloseCurlyDoubleQuote]"
}], "Text",
 CellChangeTimes->{{3.4692809157712393`*^9, 3.469280916496464*^9}, {
  3.4692827797318993`*^9, 3.469282788499905*^9}, {3.4693583873564873`*^9, 
  3.469358393097767*^9}}],

Cell[TextData[{
 "To begin we demonstrate the date and time handling capabilities of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " required for the VIX calculation. The current date and time can be \
returned using ",
 StyleBox["DateList", "MB"],
 ":"
}], "Text",
 CellChangeTimes->{{3.4694511030946198`*^9, 3.469451177894223*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"now", "=", 
  RowBox[{"DateList", "[", "]"}]}]], "Input",
 CellChangeTimes->{{3.46928082527969*^9, 3.4692808753374434`*^9}, {
   3.4692809336459913`*^9, 3.469280934451127*^9}, 3.4692811527800503`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "2009", ",", "12", ",", "18", ",", "9", ",", "32", ",", 
   "51.604806`8.465265124979176"}], "}"}]], "Output",
 CellChangeTimes->{3.469455096532353*^9, 3.469536494779201*^9, 
  3.469536547463099*^9, 3.47013917163783*^9}]
}, Open  ]],

Cell[TextData[{
 "The output is a list ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
    "year", ",", " ", "month", ",", " ", "day", ",", " ", "hour", ",", " ", 
     "minute", ",", " ", "second"}], "}"}], TraditionalForm]]],
 ". Rule replacement with pattern matching can be used to change the time to \
8:30am."
}], "Text",
 CellChangeTimes->{{3.469281171991448*^9, 3.469281181430094*^9}, {
   3.46928150156653*^9, 3.469281547941082*^9}, 3.469387327263372*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"now", "=", 
  RowBox[{"now", "/.", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x_", ",", "y_", ",", "z_", ",", "__"}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y", ",", "z", ",", "8", ",", "30", ",", "0."}], 
     "}"}]}]}]}]], "Input",
 CellChangeTimes->{{3.469281157401313*^9, 3.469281159248083*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2009", ",", "12", ",", "18", ",", "8", ",", "30", ",", "0.`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.469455096630886*^9, 3.469536494894884*^9, 
  3.469536547590486*^9, 3.470139171771021*^9}]
}, Open  ]],

Cell["\<\
In the CBOE\[RegisteredTrademark] example the near-term and next-term are 9 \
days and 37 days from now, at 8:30am on those days:\
\>", "Text",
 CellChangeTimes->{{3.4692815576225557`*^9, 3.469281579045868*^9}, {
  3.469451239410886*^9, 3.4694512741523438`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"nearTerm", "=", 
  RowBox[{"DatePlus", "[", 
   RowBox[{"now", ",", "9"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"nextTerm", "=", 
  RowBox[{"DatePlus", "[", 
   RowBox[{"now", ",", "37"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.4692809585745363`*^9, 3.4692809958443613`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2009", ",", "12", ",", "27", ",", "8", ",", "30", ",", "0"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.469455096689055*^9, 3.4695364949510937`*^9, 
  3.4695365476385193`*^9, 3.470139171827085*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2010", ",", "1", ",", "24", ",", "8", ",", "30", ",", "0"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.469455096689055*^9, 3.4695364949510937`*^9, 
  3.4695365476385193`*^9, 3.470139171831003*^9}]
}, Open  ]],

Cell["\<\
The number seconds in a year is used to determine the time to expiration (as \
a fraction of a year):\
\>", "Text",
 CellChangeTimes->{{3.469281651804553*^9, 3.4692816613758373`*^9}, {
  3.469281963834544*^9, 3.469281966791801*^9}, {3.469358427452574*^9, 
  3.46935842796989*^9}, {3.469451920063064*^9, 3.46945194383923*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"secondsPerYear", "=", 
  RowBox[{"N", "[", 
   RowBox[{"365", "*", "24", "*", "60", "*", "60"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.469281674800725*^9, 3.469281680953627*^9}, {
   3.4692817826851797`*^9, 3.469281789597188*^9}, 3.4692818211031113`*^9, {
   3.469281928474634*^9, 3.4692819567851133`*^9}}],

Cell[BoxData["3.1536`*^7"], "Output",
 CellChangeTimes->{3.4694550967189207`*^9, 3.469536494996581*^9, 
  3.46953654769269*^9, 3.470139171872157*^9}]
}, Open  ]],

Cell[TextData[{
 "The expiration time for the near-term ",
 Cell[TextData[Cell[BoxData[
  FormBox[
   SubscriptBox["\[ScriptCapitalT]", "1"], TraditionalForm]]]],
  CellChangeTimes->{{3.4692810256629066`*^9, 3.469281031644088*^9}, {
    3.469281067383277*^9, 3.4692811157043943`*^9}, {3.4692817976386547`*^9, 
    3.469281815231305*^9}, {3.4692819033364563`*^9, 3.469281906799941*^9}, 
    3.4692819416594753`*^9}],
 " and next-term",
 " ",
 Cell[TextData[Cell[BoxData[
  FormBox[
   SubscriptBox["\[ScriptCapitalT]", "2"], TraditionalForm]]]],
  CellChangeTimes->{{3.4692810256629066`*^9, 3.469281031644088*^9}, {
    3.469281067383277*^9, 3.4692811157043943`*^9}, {3.4692817976386547`*^9, 
    3.469281815231305*^9}, {3.4692819033364563`*^9, 3.469281906799941*^9}, 
    3.4692819416594753`*^9}],
 " ",
 "options are:"
}], "Text",
 CellChangeTimes->{{3.4694519796415043`*^9, 3.469452070036038*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[ScriptCapitalT]", "1"], "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"AbsoluteTime", "[", "nearTerm", "]"}], "-", 
     RowBox[{"AbsoluteTime", "[", "now", "]"}]}], ")"}], "/", 
   "secondsPerYear"}]}]], "Input",
 CellChangeTimes->{{3.4692810256629066`*^9, 3.469281031644088*^9}, {
   3.469281067383277*^9, 3.4692811157043943`*^9}, {3.4692817976386547`*^9, 
   3.469281815231305*^9}, {3.4692819033364563`*^9, 3.469281906799941*^9}, 
   3.4692819416594753`*^9}],

Cell[BoxData["0.024657534246575342`"], "Output",
 CellChangeTimes->{3.4694550967475967`*^9, 3.4695364950511637`*^9, 
  3.469536547739234*^9, 3.4701391719274178`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[ScriptCapitalT]", "2"], "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"AbsoluteTime", "[", "nextTerm", "]"}], "-", 
     RowBox[{"AbsoluteTime", "[", "now", "]"}]}], ")"}], "/", 
   "secondsPerYear"}]}]], "Input",
 CellChangeTimes->{{3.469281859152401*^9, 3.469281859446835*^9}, {
  3.4692819104098053`*^9, 3.4692819435074377`*^9}}],

Cell[BoxData["0.10136986301369863`"], "Output",
 CellChangeTimes->{3.469455096780465*^9, 3.469536495097232*^9, 
  3.469536547793359*^9, 3.470139171973239*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Risk free rate", "Subsection",
 CellChangeTimes->{{3.4692826587381496`*^9, 3.469282661336282*^9}}],

Cell[TextData[{
 "\[OpenCurlyDoubleQuote]",
 StyleBox["The risk-free interest rate, ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox["R", TraditionalForm]],
  FontSlant->"Italic"],
 StyleBox[", is the bond-equivalent yield of the U.S. T-bill maturing closest \
to the expiration dates of relevant SPX options. As such, the VIX calculation \
may use different risk-free interest rates for near- and next-term options. \
In this example, however, assume that ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   RowBox[{"R", " ", "=", " ", 
    RowBox[{"0.38", "%"}]}], TraditionalForm]],
  FontSlant->"Italic"],
 StyleBox[" for both sets of options.",
  FontSlant->"Italic"],
 "\[CloseCurlyDoubleQuote]"
}], "Text",
 CellChangeTimes->{{3.469282709867135*^9, 3.4692827111296377`*^9}, {
  3.469282765255801*^9, 3.469282774036862*^9}, {3.4693584452550573`*^9, 
  3.469358450797682*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["r", "\[ScriptF]"], "=", 
  RowBox[{"0.38", "/", "100"}]}]], "Input",
 CellChangeTimes->{{3.469282713215291*^9, 3.469282720323124*^9}, {
  3.4692849378069553`*^9, 3.4692849409252033`*^9}, {3.469358477455213*^9, 
  3.4693584781945744`*^9}}],

Cell[BoxData["0.0038`"], "Output",
 CellChangeTimes->{3.469455096814228*^9, 3.4695364951517677`*^9, 
  3.469536547838962*^9, 3.470139172026876*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Step 1. Select the options to be used in the VIX calculation\
\>", "Section",
 CellChangeTimes->{{3.469452135927124*^9, 3.469452160892785*^9}, 
   3.4701399059632072`*^9}],

Cell["Begin by importing the options data:", "Text",
 CellChangeTimes->{{3.4694521686774406`*^9, 3.469452174740325*^9}, {
  3.469536524856462*^9, 3.4695365419927177`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"near", "=", 
   RowBox[{"<<", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"NotebookDirectory", "[", "]"}], "<>", "\"\<near.dat\>\""}], 
     ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"next", "=", 
   RowBox[{"<<", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"NotebookDirectory", "[", "]"}], "<>", "\"\<next.dat\>\""}], 
     ")"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.469301307436027*^9, 3.46930131820164*^9}, {
  3.469455174412401*^9, 3.469455183466798*^9}, {3.469536536397635*^9, 
  3.4695365382450247`*^9}, {3.470139080501652*^9, 3.470139150804068*^9}}],

Cell[TextData[{
 "\[OpenCurlyDoubleQuote]",
 StyleBox["Determine the forward SPX level, F, by identifying the strike \
price at which the absolute difference between the call and put prices is \
smallest.",
  FontSlant->"Italic"],
 "\[CloseCurlyDoubleQuote]"
}], "Text",
 CellChangeTimes->{{3.4692845728850307`*^9, 3.469284576188054*^9}}],

Cell[TextData[{
 "To set this up we need to take the midpoint of bid and ask price for both \
the call and put options and then take the difference between put and call \
midpoints.\nThe imported data sets have 5 elements:  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     StyleBox[
      RowBox[{"strike", " ", "price"}],
      FontSlant->"Italic"], ",", " ", 
     StyleBox[
      RowBox[{"call", " ", "bid"}],
      FontSlant->"Italic"], 
     StyleBox[",",
      FontSlant->"Italic"], " ", 
     StyleBox[
      RowBox[{"call", " ", "ask"}],
      FontSlant->"Italic"], ",", " ", 
     StyleBox[
      RowBox[{"put", " ", "bid"}],
      FontSlant->"Italic"], ",", " ", 
     StyleBox[
      RowBox[{"put", " ", "ask"}],
      FontSlant->"Italic"]}], "}"}], TraditionalForm]]],
 ". We want to make a function to take those five elements and return a list \
containing the first element, the strike price, and the difference between \
put and call midpoints. A pure function can be written to do this:"
}], "Text",
 CellChangeTimes->{{3.4693585274136543`*^9, 3.4693585788052464`*^9}, 
   3.46935926300488*^9, {3.4694522076398697`*^9, 3.469452227766109*^9}, {
   3.469452258529413*^9, 3.4694523226559887`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makeDifferences", "=", 
  RowBox[{"Function", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x1", ",", "x2", ",", "x3", ",", "x4", ",", "x5"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x1", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{
        RowBox[{"0.5", "*", 
         RowBox[{"(", 
          RowBox[{"x2", "+", "x3"}], ")"}]}], "-", 
        RowBox[{"0.5", "*", 
         RowBox[{"(", 
          RowBox[{"x4", "+", "x5"}], ")"}]}]}], "]"}]}], "}"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.46935862612633*^9, 3.469358639145611*^9}, {
  3.469358698649447*^9, 3.4693588069169817`*^9}, {3.469358859521002*^9, 
  3.469358917729191*^9}, {3.4693590837545233`*^9, 3.46935910896631*^9}, {
  3.469359307954896*^9, 3.469359309512108*^9}, {3.469359404516589*^9, 
  3.469359412258897*^9}, {3.469454848726459*^9, 3.4694548594117603`*^9}}],

Cell[BoxData[
 RowBox[{"Function", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"x1", ",", "x2", ",", "x3", ",", "x4", ",", "x5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x1", ",", 
     RowBox[{"Abs", "[", 
      RowBox[{
       RowBox[{"0.5`", " ", 
        RowBox[{"(", 
         RowBox[{"x2", "+", "x3"}], ")"}]}], "-", 
       RowBox[{"0.5`", " ", 
        RowBox[{"(", 
         RowBox[{"x4", "+", "x5"}], ")"}]}]}], "]"}]}], "}"}]}], 
  "]"}]], "Output",
 CellChangeTimes->{3.4694550968806963`*^9, 3.469536495361496*^9, 
  3.4695365480048027`*^9, 3.470139172138245*^9}]
}, Open  ]],

Cell[TextData[{
 "In ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " pure functions such as these can be written in a shorter form:"
}], "Text",
 CellChangeTimes->{{3.469358939173365*^9, 3.46935895448543*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"#1", ",", 
    RowBox[{"Abs", "[", 
     RowBox[{
      RowBox[{"0.5", "*", 
       RowBox[{"(", 
        RowBox[{"#2", "+", "#3"}], ")"}]}], "-", 
      RowBox[{"0.5", "*", 
       RowBox[{"(", 
        RowBox[{"#4", "+", "#5"}], ")"}]}]}], "]"}]}], "}"}], "&"}]], "Input",\

 Evaluatable->False],

Cell[TextData[{
 "To apply the function to the data we can use ",
 StyleBox["Apply", "MB"],
 ":"
}], "Text",
 CellChangeTimes->{{3.469359191452197*^9, 3.469359205891218*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Apply", "[", 
  RowBox[{"makeDifferences", ",", "near", ",", "1"}], "]"}]], "Input",
 CellChangeTimes->{{3.469359215979856*^9, 3.4693592344632072`*^9}, {
   3.469359316441382*^9, 3.469359317510922*^9}, 3.46935942642864*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"200", ",", "720.1750000000001`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"250", ",", "670.225`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"300", ",", "620.375`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"350", ",", "570.375`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"375", ",", "545.35`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"400", ",", "520.325`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"425", ",", "495.975`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"450", ",", "470.375`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"470", ",", "450.35`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"475", ",", "445.35`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"480", ",", "440.325`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"490", ",", "430.075`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"500", ",", "420.325`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"510", ",", "410.325`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"520", ",", "400.15000000000003`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"525", ",", "395.125`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"530", ",", "390.77500000000003`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"540", ",", "380.20000000000005`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"550", ",", "370.45000000000005`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"560", ",", "360.275`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"570", ",", "350.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"575", ",", "345.47499999999997`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"580", ",", "340.275`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"585", ",", "335.425`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"590", ",", "330.35`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"595", ",", "326.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"600", ",", "320.425`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"605", ",", "315.50000000000006`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"610", ",", "310.40000000000003`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"615", ",", "305.42499999999995`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"620", ",", "300.47499999999997`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"625", ",", "295.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"630", ",", "290.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"635", ",", "285.52500000000003`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"640", ",", "280.425`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"645", ",", "275.54999999999995`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"650", ",", "270.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"655", ",", "265.575`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"660", ",", "260.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"665", ",", "255.79999999999995`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"670", ",", "250.575`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"675", ",", "245.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"680", ",", "240.64999999999998`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"690", ",", "230.625`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"700", ",", "220.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"710", ",", "210.65`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"720", ",", "200.79999999999998`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"725", ",", "195.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"730", ",", "190.65`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"740", ",", "180.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"750", ",", "170.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"760", ",", "160.67499999999998`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"770", ",", "150.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"775", ",", "145.79999999999998`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"780", ",", "140.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"790", ",", "131.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"800", ",", "121.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"805", ",", "115.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"810", ",", "110.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"815", ",", "105.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"820", ",", "100.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"825", ",", "96.10000000000001`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"830", ",", "90.69999999999999`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"835", ",", "86.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"840", ",", "80.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"845", ",", "75.95000000000002`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"850", ",", "70.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"855", ",", "65.80000000000001`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"860", ",", "60.800000000000004`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"865", ",", "55.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"870", ",", "50.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"875", ",", "45.999999999999986`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"880", ",", "40.949999999999996`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"885", ",", "36.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"890", ",", "31.599999999999994`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"895", ",", "26.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"900", ",", "21.700000000000003`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"905", ",", "16.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"910", ",", "10.849999999999994`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"915", ",", "6.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"920", ",", "0.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"925", ",", "4.400000000000006`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"930", ",", "7.699999999999996`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"935", ",", "13.950000000000003`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"940", ",", "17.799999999999997`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"945", ",", "23.950000000000003`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"950", ",", "27.35`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"955", ",", "34.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"960", ",", "39.349999999999994`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"965", ",", "44.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"970", ",", "49.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"975", ",", "53.25000000000001`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"980", ",", "59.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"985", ",", "64.14999999999999`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"990", ",", "69.14999999999999`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"995", ",", "74.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1000", ",", "78.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1005", ",", "84.10000000000001`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1010", ",", "89.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1015", ",", "94.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1020", ",", "98.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1025", ",", "104.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1030", ",", "108.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1035", ",", "114.19999999999999`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1040", ",", "119.125`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1045", ",", "124.225`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1050", ",", "128.89999999999998`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1055", ",", "134.225`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1060", ",", "138.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1065", ",", "144.225`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1070", ",", "149.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1075", ",", "153.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1080", ",", "158.975`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1085", ",", "164.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1090", ",", "168.925`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1095", ",", "173.975`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1100", ",", "179.025`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1105", ",", "183.875`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1110", ",", "189.025`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1115", ",", "193.875`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1120", ",", "199.025`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1125", ",", "203.925`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1130", ",", "208.725`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1135", ",", "213.725`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1140", ",", "218.825`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1145", ",", "223.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1150", ",", "229.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1155", ",", "233.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1160", ",", "238.92499999999998`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1165", ",", "244.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1170", ",", "248.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1175", ",", "254.04999999999998`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1180", ",", "258.72499999999997`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1185", ",", "263.35`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1190", ",", "268.82500000000005`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1195", ",", "273.57500000000005`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1200", ",", "279.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1205", ",", "283.57500000000005`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1210", ",", "288.82500000000005`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1215", ",", "293.82500000000005`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1220", ",", "298.57500000000005`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1225", ",", "303.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1230", ",", "308.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1235", ",", "313.725`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1240", ",", "318.85`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1245", ",", "324.02500000000003`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1250", ",", "329.02500000000003`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1255", ",", "333.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1260", ",", "338.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1265", ",", "343.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1270", ",", "348.95000000000005`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1275", ",", "354.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1280", ",", "359.02500000000003`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1285", ",", "364.02500000000003`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1290", ",", "369.02500000000003`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1295", ",", "374.02500000000003`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1300", ",", "379.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1305", ",", "384.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1310", ",", "389.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1315", ",", "394.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1320", ",", "398.90000000000003`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1325", ",", "404.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1330", ",", "409.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1335", ",", "414.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1340", ",", "419.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1345", ",", "424.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1350", ",", "428.375`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1355", ",", "433.34999999999997`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1360", ",", "438.34999999999997`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1365", ",", "443.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1370", ",", "448.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1375", ",", "453.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1380", ",", "458.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1385", ",", "463.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1390", ",", "468.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1395", ",", "473.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1400", ",", "478.975`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1405", ",", "483.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1410", ",", "488.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1415", ",", "493.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1420", ",", "498.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1425", ",", "503.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1430", ",", "508.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1435", ",", "513.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1440", ",", "518.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1445", ",", "523.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1450", ",", "528.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1460", ",", "538.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1470", ",", "548.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1475", ",", "553.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1480", ",", "558.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1490", ",", "568.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1500", ",", "578.975`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1650", ",", "728.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1700", ",", "778.35`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.469455096923368*^9, 3.469536495411878*^9, 
  3.469536548069227*^9, 3.470139172200856*^9}]
}, Open  ]],

Cell[TextData[{
 "Apply can also be written in shortform. In this example, where the function \
is being applied to the first level of the list, the shortform is ",
 StyleBox["@@@", "MB"],
 ". The shortform expression to create the list needed is therefore:"
}], "Text",
 CellChangeTimes->{{3.469359444177824*^9, 3.469359499001586*^9}, 
   3.469452363179549*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tmp1", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"#1", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{
        RowBox[{"0.5", "*", 
         RowBox[{"(", 
          RowBox[{"#2", "+", "#3"}], ")"}]}], "-", 
        RowBox[{"0.5", "*", 
         RowBox[{"(", 
          RowBox[{"#4", "+", "#5"}], ")"}]}]}], "]"}]}], "}"}], "&"}], "@@@", 
   "near"}]}]], "Input",
 CellChangeTimes->{{3.469301465243476*^9, 3.469301465884897*^9}, {
  3.4693015514085293`*^9, 3.469301589400929*^9}, {3.469301756398755*^9, 
  3.469301769976883*^9}, {3.4693018617212563`*^9, 3.4693018630713577`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"200", ",", "720.1750000000001`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"250", ",", "670.225`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"300", ",", "620.375`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"350", ",", "570.375`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"375", ",", "545.35`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"400", ",", "520.325`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"425", ",", "495.975`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"450", ",", "470.375`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"470", ",", "450.35`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"475", ",", "445.35`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"480", ",", "440.325`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"490", ",", "430.075`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"500", ",", "420.325`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"510", ",", "410.325`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"520", ",", "400.15000000000003`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"525", ",", "395.125`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"530", ",", "390.77500000000003`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"540", ",", "380.20000000000005`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"550", ",", "370.45000000000005`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"560", ",", "360.275`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"570", ",", "350.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"575", ",", "345.47499999999997`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"580", ",", "340.275`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"585", ",", "335.425`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"590", ",", "330.35`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"595", ",", "326.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"600", ",", "320.425`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"605", ",", "315.50000000000006`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"610", ",", "310.40000000000003`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"615", ",", "305.42499999999995`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"620", ",", "300.47499999999997`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"625", ",", "295.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"630", ",", "290.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"635", ",", "285.52500000000003`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"640", ",", "280.425`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"645", ",", "275.54999999999995`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"650", ",", "270.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"655", ",", "265.575`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"660", ",", "260.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"665", ",", "255.79999999999995`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"670", ",", "250.575`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"675", ",", "245.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"680", ",", "240.64999999999998`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"690", ",", "230.625`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"700", ",", "220.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"710", ",", "210.65`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"720", ",", "200.79999999999998`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"725", ",", "195.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"730", ",", "190.65`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"740", ",", "180.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"750", ",", "170.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"760", ",", "160.67499999999998`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"770", ",", "150.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"775", ",", "145.79999999999998`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"780", ",", "140.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"790", ",", "131.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"800", ",", "121.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"805", ",", "115.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"810", ",", "110.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"815", ",", "105.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"820", ",", "100.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"825", ",", "96.10000000000001`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"830", ",", "90.69999999999999`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"835", ",", "86.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"840", ",", "80.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"845", ",", "75.95000000000002`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"850", ",", "70.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"855", ",", "65.80000000000001`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"860", ",", "60.800000000000004`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"865", ",", "55.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"870", ",", "50.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"875", ",", "45.999999999999986`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"880", ",", "40.949999999999996`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"885", ",", "36.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"890", ",", "31.599999999999994`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"895", ",", "26.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"900", ",", "21.700000000000003`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"905", ",", "16.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"910", ",", "10.849999999999994`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"915", ",", "6.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"920", ",", "0.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"925", ",", "4.400000000000006`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"930", ",", "7.699999999999996`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"935", ",", "13.950000000000003`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"940", ",", "17.799999999999997`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"945", ",", "23.950000000000003`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"950", ",", "27.35`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"955", ",", "34.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"960", ",", "39.349999999999994`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"965", ",", "44.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"970", ",", "49.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"975", ",", "53.25000000000001`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"980", ",", "59.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"985", ",", "64.14999999999999`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"990", ",", "69.14999999999999`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"995", ",", "74.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1000", ",", "78.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1005", ",", "84.10000000000001`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1010", ",", "89.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1015", ",", "94.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1020", ",", "98.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1025", ",", "104.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1030", ",", "108.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1035", ",", "114.19999999999999`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1040", ",", "119.125`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1045", ",", "124.225`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1050", ",", "128.89999999999998`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1055", ",", "134.225`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1060", ",", "138.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1065", ",", "144.225`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1070", ",", "149.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1075", ",", "153.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1080", ",", "158.975`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1085", ",", "164.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1090", ",", "168.925`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1095", ",", "173.975`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1100", ",", "179.025`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1105", ",", "183.875`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1110", ",", "189.025`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1115", ",", "193.875`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1120", ",", "199.025`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1125", ",", "203.925`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1130", ",", "208.725`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1135", ",", "213.725`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1140", ",", "218.825`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1145", ",", "223.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1150", ",", "229.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1155", ",", "233.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1160", ",", "238.92499999999998`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1165", ",", "244.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1170", ",", "248.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1175", ",", "254.04999999999998`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1180", ",", "258.72499999999997`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1185", ",", "263.35`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1190", ",", "268.82500000000005`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1195", ",", "273.57500000000005`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1200", ",", "279.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1205", ",", "283.57500000000005`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1210", ",", "288.82500000000005`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1215", ",", "293.82500000000005`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1220", ",", "298.57500000000005`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1225", ",", "303.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1230", ",", "308.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1235", ",", "313.725`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1240", ",", "318.85`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1245", ",", "324.02500000000003`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1250", ",", "329.02500000000003`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1255", ",", "333.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1260", ",", "338.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1265", ",", "343.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1270", ",", "348.95000000000005`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1275", ",", "354.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1280", ",", "359.02500000000003`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1285", ",", "364.02500000000003`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1290", ",", "369.02500000000003`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1295", ",", "374.02500000000003`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1300", ",", "379.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1305", ",", "384.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1310", ",", "389.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1315", ",", "394.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1320", ",", "398.90000000000003`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1325", ",", "404.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1330", ",", "409.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1335", ",", "414.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1340", ",", "419.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1345", ",", "424.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1350", ",", "428.375`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1355", ",", "433.34999999999997`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1360", ",", "438.34999999999997`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1365", ",", "443.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1370", ",", "448.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1375", ",", "453.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1380", ",", "458.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1385", ",", "463.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1390", ",", "468.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1395", ",", "473.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1400", ",", "478.975`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1405", ",", "483.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1410", ",", "488.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1415", ",", "493.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1420", ",", "498.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1425", ",", "503.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1430", ",", "508.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1435", ",", "513.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1440", ",", "518.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1445", ",", "523.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1450", ",", "528.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1460", ",", "538.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1470", ",", "548.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1475", ",", "553.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1480", ",", "558.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1490", ",", "568.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1500", ",", "578.975`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1650", ",", "728.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1700", ",", "778.35`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.469455096968924*^9, 3.469536495450636*^9, 
  3.469536548129016*^9, 3.4701391722977457`*^9}]
}, Open  ]],

Cell["Repeat for the next-term options:", "Text",
 CellChangeTimes->{{3.4693597078475533`*^9, 3.469359713358343*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tmp2", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"#1", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{
        RowBox[{"0.5", "*", 
         RowBox[{"(", 
          RowBox[{"#2", "+", "#3"}], ")"}]}], "-", 
        RowBox[{"0.5", "*", 
         RowBox[{"(", 
          RowBox[{"#4", "+", "#5"}], ")"}]}]}], "]"}]}], "}"}], "&"}], "@@@", 
   "next"}]}]], "Input",
 CellChangeTimes->{{3.469301887745508*^9, 3.469301909464756*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"200", ",", "718.5749999999999`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"300", ",", "618.8000000000001`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"350", ",", "568.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"375", ",", "544.1999999999999`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"400", ",", "519.075`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"425", ",", "494.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"450", ",", "469.35`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"475", ",", "444.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"500", ",", "419.175`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"525", ",", "394.525`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"550", ",", "369.95000000000005`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"575", ",", "344.84999999999997`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"600", ",", "320.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"610", ",", "310.34999999999997`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"615", ",", "304.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"620", ",", "300.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"625", ",", "294.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"630", ",", "289.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"635", ",", "284.95000000000005`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"640", ",", "280.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"650", ",", "269.90000000000003`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"660", ",", "259.85`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"670", ",", "250.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"675", ",", "245.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"680", ",", "239.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"690", ",", "230.35`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"700", ",", "220.29999999999998`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"710", ",", "210.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"720", ",", "200.35`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"725", ",", "195.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"730", ",", "190.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"740", ",", "180.29999999999998`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"750", ",", "170.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"760", ",", "160.64999999999998`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"770", ",", "150.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"775", ",", "145.20000000000002`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"780", ",", "140.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"790", ",", "130.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"800", ",", "119.05000000000001`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"805", ",", "115.10000000000001`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"810", ",", "110.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"815", ",", "105.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"820", ",", "100.24999999999997`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"825", ",", "95.25000000000001`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"830", ",", "90.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"835", ",", "85.35`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"840", ",", "80.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"845", ",", "75.35000000000001`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"850", ",", "71.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"855", ",", "66.35`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"860", ",", "60.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"865", ",", "56.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"870", ",", "51.10000000000001`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"875", ",", "45.849999999999994`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"880", ",", "40.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"885", ",", "35.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"890", ",", "30.700000000000003`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"895", ",", "25.549999999999997`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"900", ",", "20.799999999999997`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"905", ",", "15.649999999999991`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"910", ",", "10.599999999999994`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"915", ",", "5.850000000000001`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"920", ",", "1.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"925", ",", "4.099999999999994`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"930", ",", "9.650000000000006`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"935", ",", "14.299999999999997`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"940", ",", "19.64999999999999`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"945", ",", "24.200000000000003`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"950", ",", "28.150000000000006`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"955", ",", "34.35000000000001`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"960", ",", "39.14999999999999`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"965", ",", "44.39999999999999`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"970", ",", "49.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"975", ",", "53.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"980", ",", "59.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"985", ",", "64.69999999999999`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"990", ",", "69.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"995", ",", "74.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1000", ",", "78.89999999999999`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1005", ",", "84.55000000000001`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1010", ",", "89.45000000000002`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1015", ",", "94.54999999999998`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1020", ",", "98.29999999999998`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1025", ",", "104.50000000000001`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1030", ",", "109.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1035", ",", "114.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1040", ",", "118.85000000000001`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1045", ",", "124.39999999999999`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1050", ",", "128.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1055", ",", "134.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1060", ",", "138.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1065", ",", "143.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1070", ",", "149.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1075", ",", "153.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1080", ",", "159.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1085", ",", "164.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1090", ",", "169.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1095", ",", "174.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1100", ",", "178.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1105", ",", "183.89999999999998`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1110", ",", "189.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1115", ",", "194.225`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1120", ",", "199.175`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1125", ",", "203.45000000000002`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1130", ",", "209.35`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1135", ",", "214.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1140", ",", "219.125`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1145", ",", "224.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1150", ",", "229.32500000000002`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1155", ",", "234.32500000000002`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1160", ",", "238.85`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1165", ",", "243.85`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1170", ",", "249.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1175", ",", "254.075`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1180", ",", "259.175`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1185", ",", "263.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1190", ",", "269.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1195", ",", "273.42499999999995`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1200", ",", "278.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1205", ",", "283.975`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1210", ",", "289.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1215", ",", "293.875`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1220", ",", "298.925`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1225", ",", "303.85`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1230", ",", "308.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1235", ",", "313.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1240", ",", "318.775`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1245", ",", "323.825`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1250", ",", "328.45`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1255", ",", "333.775`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1260", ",", "338.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1265", ",", "343.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1270", ",", "348.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1275", ",", "353.975`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1280", ",", "358.725`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1290", ",", "368.725`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1300", ",", "378.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1315", ",", "393.04999999999995`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1320", ",", "398.625`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1325", ",", "402.65`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1335", ",", "413.625`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1340", ",", "418.625`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1345", ",", "423.625`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1350", ",", "427.95000000000005`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1360", ",", "437.92499999999995`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1375", ",", "453.625`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1380", ",", "458.525`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1395", ",", "473.65`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1400", ",", "477.85`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1420", ",", "498.425`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1425", ",", "503.425`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1440", ",", "518.425`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1450", ",", "527.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1475", ",", "553.325`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1480", ",", "558.325`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1500", ",", "577.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1525", ",", "603.225`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1550", ",", "627.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1575", ",", "653.175`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1600", ",", "677.35`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1625", ",", "703.075`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1650", ",", "726.85`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1680", ",", "757.975`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1690", ",", "767.925`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1700", ",", "778.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1735", ",", "812.875`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1750", ",", "827.825`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1775", ",", "853.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1800", ",", "877.725`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1850", ",", "927.625`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1900", ",", "977.1999999999999`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1950", ",", "1027.475`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2000", ",", "1077.2`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.469455097018423*^9, 3.469536495497851*^9, 
  3.469536548195265*^9, 3.4701391723985977`*^9}]
}, Open  ]],

Cell[TextData[{
 "We want to extract the data at which the absolute difference between the \
call and put prices is smallest. One way to do this is to use ",
 StyleBox["Cases", "MB"],
 " and apply a condition that the second element, i.e. the absolute \
difference between the call and put prices, must equal the minimum, the \
smallest value."
}], "Text",
 CellChangeTimes->{{3.469284799626416*^9, 3.469284837986952*^9}, {
  3.469453338633481*^9, 3.469453397839773*^9}, {3.46945344574739*^9, 
  3.4694534791380653`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Cases", "[", 
  RowBox[{"tmp1", ",", 
   RowBox[{"x_", "/;", 
    RowBox[{
     RowBox[{"x", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
     "\[Equal]", 
     RowBox[{"Min", "[", 
      RowBox[{"tmp1", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], "]"}]}]}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Cases", "[", 
  RowBox[{"tmp2", ",", 
   RowBox[{"x_", "/;", 
    RowBox[{
     RowBox[{"x", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
     "\[Equal]", 
     RowBox[{"Min", "[", 
      RowBox[{"tmp2", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], "]"}]}]}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.469453277231691*^9, 3.469453308335967*^9}, {
  3.469453529686809*^9, 3.469453535230133*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"920", ",", "0.5`"}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.469455097065234*^9, 3.469536495551757*^9, 
  3.4695365482592373`*^9, 3.470139172494452*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"920", ",", "1.`"}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.469455097065234*^9, 3.469536495551757*^9, 
  3.4695365482592373`*^9, 3.470139172546311*^9}]
}, Open  ]],

Cell["\<\
Alternatively the data could be sorted and the first element of the sorted \
list selected:\
\>", "Text",
 CellChangeTimes->{{3.469453493811091*^9, 3.469453516514461*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"F1Data", "=", 
  RowBox[{"First", "@", 
   RowBox[{"Sort", "[", 
    RowBox[{"tmp1", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"#1", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
       "<", 
       RowBox[{"#2", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}],
       "&"}]}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"F2Data", "=", 
  RowBox[{"First", "@", 
   RowBox[{"Sort", "[", 
    RowBox[{"tmp2", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"#1", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
       "<", 
       RowBox[{"#2", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}],
       "&"}]}], "]"}]}]}]}], "Input",
 CellChangeTimes->{{3.469284707904717*^9, 3.469284748089012*^9}, {
  3.4692847818997707`*^9, 3.4692848186759977`*^9}, {3.469301828823539*^9, 
  3.469301871599127*^9}, {3.469301903384563*^9, 3.469301922865415*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"920", ",", "0.5`"}], "}"}]], "Output",
 CellChangeTimes->{3.46945509709866*^9, 3.469536495628083*^9, 
  3.4695365483042517`*^9, 3.470139172604631*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"920", ",", "1.`"}], "}"}]], "Output",
 CellChangeTimes->{3.46945509709866*^9, 3.469536495628083*^9, 
  3.4695365483042517`*^9, 3.470139172646245*^9}]
}, Open  ]],

Cell["This data is then used to calculate the forward index price:", "Text",
 CellChangeTimes->{{3.4692848572831173`*^9, 3.469284866929982*^9}, {
  3.469453554998633*^9, 3.469453562579568*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  SubscriptBox["\[ScriptCapitalF]", "1"], "=", 
  RowBox[{
   RowBox[{"F1Data", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
   "+", 
   RowBox[{
    RowBox[{"F1Data", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
    "*", 
    RowBox[{"Exp", "[", 
     RowBox[{
      SubscriptBox["r", "\[ScriptF]"], "*", 
      SubscriptBox["\[ScriptCapitalT]", "1"]}], 
     "]"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["\[ScriptCapitalF]", "2"], "=", 
  RowBox[{
   RowBox[{"F2Data", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
   "+", 
   RowBox[{
    RowBox[{"F2Data", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
    "*", 
    RowBox[{"Exp", "[", 
     RowBox[{
      SubscriptBox["r", "\[ScriptF]"], "*", 
      SubscriptBox["\[ScriptCapitalT]", "2"]}], "]"}]}]}]}]}], "Input",
 CellChangeTimes->{{3.469284872710161*^9, 3.469284919173503*^9}, {
  3.469284994289609*^9, 3.469285018896555*^9}, {3.4692933166292067`*^9, 
  3.469293318500828*^9}, {3.469302102521229*^9, 3.46930210468603*^9}}],

Cell[BoxData["920.50004685151`"], "Output",
 CellChangeTimes->{3.469455097131084*^9, 3.4695364957781763`*^9, 
  3.469536548358531*^9, 3.470139172803371*^9}],

Cell[BoxData["921.0003852796806`"], "Output",
 CellChangeTimes->{3.469455097131084*^9, 3.4695364957781763`*^9, 
  3.469536548358531*^9, 3.470139172846218*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Process options data", "Subsection",
 CellChangeTimes->{{3.469365342176537*^9, 3.469365345541132*^9}}],

Cell[TextData[{
 "\[OpenCurlyDoubleQuote]",
 StyleBox["Next, determine ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["K", 
    StyleBox["0",
     FontSlant->"Plain"]], TraditionalForm]],
  FontSlant->"Italic"],
 StyleBox[" - the strike price immediately below the forward index level, ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox["F", TraditionalForm]],
  FontSlant->"Italic"],
 StyleBox[" - for the near- and next-term options.",
  FontSlant->"Italic"],
 "\[CloseCurlyDoubleQuote]"
}], "Text",
 CellChangeTimes->{{3.469285369497106*^9, 3.469285379069819*^9}, {
   3.469302162438905*^9, 3.469302168389542*^9}, 3.46936127923584*^9}],

Cell[TextData[{
 "The function ",
 StyleBox["Select", "MB"],
 " allows you to select values below the forward index level:"
}], "Text",
 CellChangeTimes->{{3.469361319619544*^9, 3.46936133908251*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Select", "[", 
  RowBox[{
   RowBox[{"tmp1", "\[LeftDoubleBracket]", 
    RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
   RowBox[{
    RowBox[{"#", "<", 
     SubscriptBox["\[ScriptCapitalF]", "1"]}], "&"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.469285527036515*^9, 3.469285551988893*^9}, 
   3.4692933341247396`*^9, {3.469302217561591*^9, 3.469302218382864*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "200", ",", "250", ",", "300", ",", "350", ",", "375", ",", "400", ",", 
   "425", ",", "450", ",", "470", ",", "475", ",", "480", ",", "490", ",", 
   "500", ",", "510", ",", "520", ",", "525", ",", "530", ",", "540", ",", 
   "550", ",", "560", ",", "570", ",", "575", ",", "580", ",", "585", ",", 
   "590", ",", "595", ",", "600", ",", "605", ",", "610", ",", "615", ",", 
   "620", ",", "625", ",", "630", ",", "635", ",", "640", ",", "645", ",", 
   "650", ",", "655", ",", "660", ",", "665", ",", "670", ",", "675", ",", 
   "680", ",", "690", ",", "700", ",", "710", ",", "720", ",", "725", ",", 
   "730", ",", "740", ",", "750", ",", "760", ",", "770", ",", "775", ",", 
   "780", ",", "790", ",", "800", ",", "805", ",", "810", ",", "815", ",", 
   "820", ",", "825", ",", "830", ",", "835", ",", "840", ",", "845", ",", 
   "850", ",", "855", ",", "860", ",", "865", ",", "870", ",", "875", ",", 
   "880", ",", "885", ",", "890", ",", "895", ",", "900", ",", "905", ",", 
   "910", ",", "915", ",", "920"}], "}"}]], "Output",
 CellChangeTimes->{3.469455097165202*^9, 3.469536496044958*^9, 
  3.469536548404435*^9, 3.470139172921856*^9}]
}, Open  ]],

Cell["\<\
The maximum of these values is the value immediately below the forward index \
level:\
\>", "Text",
 CellChangeTimes->{{3.46936134907607*^9, 3.469361372732993*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[ScriptCapitalK]", "0"], "=", 
  RowBox[{"Max", "[", 
   RowBox[{"Select", "[", 
    RowBox[{
     RowBox[{"tmp1", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
     RowBox[{
      RowBox[{"#", "<", 
       SubscriptBox["\[ScriptCapitalF]", "1"]}], "&"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.469285569895954*^9, 3.469285576357007*^9}, {
   3.469288904801992*^9, 3.469288939336255*^9}, 3.469293336772064*^9, {
   3.469302227617012*^9, 3.4693022284873543`*^9}}],

Cell[BoxData["920"], "Output",
 CellChangeTimes->{3.46945509719801*^9, 3.469536496160915*^9, 
  3.46953654845918*^9, 3.470139172992283*^9}]
}, Open  ]],

Cell[TextData[{
 "Select out-of-the-money put options with strike prices ",
 Cell[BoxData[
  FormBox[
   RowBox[{"<", " ", 
    SubscriptBox["K", "0"]}], TraditionalForm]]],
 ". The data list has the form {",
 StyleBox["strike price",
  FontSlant->"Italic"],
 ", ",
 StyleBox["call bid",
  FontSlant->"Italic"],
 ", ",
 StyleBox["call ask",
  FontSlant->"Italic"],
 ", ",
 StyleBox["put bid",
  FontSlant->"Italic"],
 ", ",
 StyleBox["put ask",
  FontSlant->"Italic"],
 "}. Only the strike pice and puts are required, these are the first, fourth, \
and fifth elements in the list. The code below selects all elements where the \
first element, ",
 StyleBox["#\[LeftDoubleBracket]1\[RightDoubleBracket]", "MB"],
 ", is less than ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["K", "0"], TraditionalForm]]],
 "."
}], "Text",
 CellChangeTimes->{
  3.469291202637772*^9, {3.469361453542776*^9, 3.469361465342044*^9}, {
   3.469361538233996*^9, 3.469361539967432*^9}, {3.4693615963538437`*^9, 
   3.469361776333612*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Cases", "[", 
  RowBox[{
   RowBox[{"near", "\[LeftDoubleBracket]", 
    RowBox[{"All", ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4", ",", "5"}], "}"}]}], "\[RightDoubleBracket]"}], 
   ",", 
   RowBox[{"x_", "/;", 
    RowBox[{
     RowBox[{"x", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "<", 
     SubscriptBox["\[ScriptCapitalK]", "0"]}]}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"200", ",", "0.`", ",", "0.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"250", ",", "0.`", ",", "0.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"300", ",", "0.`", ",", "0.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"350", ",", "0.`", ",", "0.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"375", ",", "0.`", ",", "0.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"400", ",", "0.05`", ",", "0.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"425", ",", "0.05`", ",", "0.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"450", ",", "0.05`", ",", "0.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"470", ",", "0.05`", ",", "0.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"475", ",", "0.05`", ",", "0.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"480", ",", "0.05`", ",", "0.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"490", ",", "0.05`", ",", "0.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"500", ",", "0.05`", ",", "0.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"510", ",", "0.05`", ",", "0.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"520", ",", "0.05`", ",", "0.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"525", ",", "0.05`", ",", "0.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"530", ",", "0.05`", ",", "0.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"540", ",", "0.05`", ",", "0.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"550", ",", "0.1`", ",", "0.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"560", ",", "0.05`", ",", "0.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"570", ",", "0.05`", ",", "0.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"575", ",", "0.05`", ",", "0.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"580", ",", "0.05`", ",", "0.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"585", ",", "0.1`", ",", "0.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"590", ",", "0.05`", ",", "0.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"595", ",", "0.05`", ",", "0.45`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"600", ",", "0.25`", ",", "0.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"605", ",", "0.1`", ",", "0.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"610", ",", "0.1`", ",", "0.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"615", ",", "0.1`", ",", "0.85`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"620", ",", "0.1`", ",", "0.85`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"625", ",", "0.4`", ",", "0.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"630", ",", "0.1`", ",", "0.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"635", ",", "0.1`", ",", "0.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"640", ",", "0.3`", ",", "1.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"645", ",", "0.1`", ",", "1.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"650", ",", "0.5`", ",", "1.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"655", ",", "0.2`", ",", "1.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"660", ",", "0.3`", ",", "1.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"665", ",", "0.2`", ",", "1.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"670", ",", "0.4`", ",", "1.45`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"675", ",", "0.5`", ",", "1.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"680", ",", "0.55`", ",", "1.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"690", ",", "0.7`", ",", "1.85`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"700", ",", "1.3`", ",", "1.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"710", ",", "1.1`", ",", "2.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"720", ",", "1.1`", ",", "3.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"725", ",", "2.`", ",", "3.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"730", ",", "1.4`", ",", "3.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"740", ",", "1.8`", ",", "4.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"750", ",", "3.2`", ",", "3.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"760", ",", "2.85`", ",", "5.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"770", ",", "4.`", ",", "5.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"775", ",", "3.9`", ",", "5.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"780", ",", "4.1`", ",", "6.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"790", ",", "4.9`", ",", "7.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"800", ",", "6.1`", ",", "7.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"805", ",", "6.4`", ",", "9.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"810", ",", "7.1`", ",", "9.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"815", ",", "7.5`", ",", "10.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"820", ",", "8.2`", ",", "10.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"825", ",", "8.9`", ",", "11.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"830", ",", "9.`", ",", "13.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"835", ",", "9.8`", ",", "13.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"840", ",", "10.6`", ",", "14.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"845", ",", "11.5`", ",", "15.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"850", ",", "13.5`", ",", "16.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"855", ",", "13.5`", ",", "17.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"860", ",", "14.5`", ",", "18.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"865", ",", "15.5`", ",", "19.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"870", ",", "17.1`", ",", "20.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"875", ",", "18.2`", ",", "22.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"880", ",", "19.2`", ",", "24.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"885", ",", "20.3`", ",", "25.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"890", ",", "22.1`", ",", "26.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"895", ",", "23.9`", ",", "29.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"900", ",", "25.5`", ",", "29.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"905", ",", "27.2`", ",", "32.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"910", ",", "29.2`", ",", "34.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"915", ",", "30.8`", ",", "36.3`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.46945509723361*^9, 3.4695364962448587`*^9, 
  3.4695365485108643`*^9, 3.47013917307292*^9}]
}, Open  ]],

Cell[TextData[{
 "As above ",
 StyleBox["Select", "MB"],
 " can be used as an alternative function to obtain this list:"
}], "Text",
 CellChangeTimes->{{3.469453783473852*^9, 3.469453811777027*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"puts", "=", 
  RowBox[{"Select", "[", 
   RowBox[{
    RowBox[{"near", "\[LeftDoubleBracket]", 
     RowBox[{"All", ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "4", ",", "5"}], "}"}]}], "\[RightDoubleBracket]"}], 
    ",", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      "<", 
      SubscriptBox["\[ScriptCapitalK]", "0"]}], "&"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.469291210265544*^9, 3.469291285182592*^9}, {
   3.469302267972005*^9, 3.469302272416209*^9}, {3.469361685624207*^9, 
   3.469361696461825*^9}, 3.469361789418681*^9, {3.469361841100613*^9, 
   3.469361842297308*^9}, {3.469365523688156*^9, 3.469365524004772*^9}, {
   3.469365625071521*^9, 3.469365625358913*^9}, {3.469453753722392*^9, 
   3.469453763906385*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"200", ",", "0.`", ",", "0.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"250", ",", "0.`", ",", "0.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"300", ",", "0.`", ",", "0.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"350", ",", "0.`", ",", "0.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"375", ",", "0.`", ",", "0.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"400", ",", "0.05`", ",", "0.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"425", ",", "0.05`", ",", "0.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"450", ",", "0.05`", ",", "0.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"470", ",", "0.05`", ",", "0.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"475", ",", "0.05`", ",", "0.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"480", ",", "0.05`", ",", "0.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"490", ",", "0.05`", ",", "0.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"500", ",", "0.05`", ",", "0.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"510", ",", "0.05`", ",", "0.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"520", ",", "0.05`", ",", "0.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"525", ",", "0.05`", ",", "0.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"530", ",", "0.05`", ",", "0.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"540", ",", "0.05`", ",", "0.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"550", ",", "0.1`", ",", "0.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"560", ",", "0.05`", ",", "0.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"570", ",", "0.05`", ",", "0.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"575", ",", "0.05`", ",", "0.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"580", ",", "0.05`", ",", "0.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"585", ",", "0.1`", ",", "0.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"590", ",", "0.05`", ",", "0.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"595", ",", "0.05`", ",", "0.45`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"600", ",", "0.25`", ",", "0.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"605", ",", "0.1`", ",", "0.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"610", ",", "0.1`", ",", "0.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"615", ",", "0.1`", ",", "0.85`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"620", ",", "0.1`", ",", "0.85`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"625", ",", "0.4`", ",", "0.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"630", ",", "0.1`", ",", "0.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"635", ",", "0.1`", ",", "0.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"640", ",", "0.3`", ",", "1.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"645", ",", "0.1`", ",", "1.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"650", ",", "0.5`", ",", "1.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"655", ",", "0.2`", ",", "1.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"660", ",", "0.3`", ",", "1.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"665", ",", "0.2`", ",", "1.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"670", ",", "0.4`", ",", "1.45`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"675", ",", "0.5`", ",", "1.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"680", ",", "0.55`", ",", "1.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"690", ",", "0.7`", ",", "1.85`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"700", ",", "1.3`", ",", "1.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"710", ",", "1.1`", ",", "2.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"720", ",", "1.1`", ",", "3.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"725", ",", "2.`", ",", "3.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"730", ",", "1.4`", ",", "3.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"740", ",", "1.8`", ",", "4.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"750", ",", "3.2`", ",", "3.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"760", ",", "2.85`", ",", "5.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"770", ",", "4.`", ",", "5.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"775", ",", "3.9`", ",", "5.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"780", ",", "4.1`", ",", "6.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"790", ",", "4.9`", ",", "7.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"800", ",", "6.1`", ",", "7.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"805", ",", "6.4`", ",", "9.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"810", ",", "7.1`", ",", "9.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"815", ",", "7.5`", ",", "10.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"820", ",", "8.2`", ",", "10.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"825", ",", "8.9`", ",", "11.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"830", ",", "9.`", ",", "13.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"835", ",", "9.8`", ",", "13.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"840", ",", "10.6`", ",", "14.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"845", ",", "11.5`", ",", "15.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"850", ",", "13.5`", ",", "16.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"855", ",", "13.5`", ",", "17.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"860", ",", "14.5`", ",", "18.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"865", ",", "15.5`", ",", "19.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"870", ",", "17.1`", ",", "20.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"875", ",", "18.2`", ",", "22.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"880", ",", "19.2`", ",", "24.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"885", ",", "20.3`", ",", "25.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"890", ",", "22.1`", ",", "26.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"895", ",", "23.9`", ",", "29.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"900", ",", "25.5`", ",", "29.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"905", ",", "27.2`", ",", "32.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"910", ",", "29.2`", ",", "34.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"915", ",", "30.8`", ",", "36.3`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.469455097267274*^9, 3.469536496360426*^9, 
  3.469536548654642*^9, 3.469536603616727*^9, 3.470139173160735*^9}]
}, Open  ]],

Cell[TextData[{
 "\[OpenCurlyDoubleQuote]",
 StyleBox["\[Ellipsis] once two puts with consecutive strike prices are found \
to have zero bid prices, no puts with lower strikes are considered for \
inclusion.",
  FontSlant->"Italic"],
 "\[CloseCurlyDoubleQuote]"
}], "Text",
 CellChangeTimes->{{3.469290319638431*^9, 3.469290330038061*^9}, 
   3.469453832572385*^9}],

Cell[TextData[{
 "To apply this condition, search for elements in the list that match a \
pattern of two successive bid prices of zero:\n{\[Ellipsis], ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     RowBox[{"strike", " ", "price"}], ",", " ", "0.", ",", " ", "ask"}], 
    "}"}], TraditionalForm]]],
 ", {strike price, 0., ask},\[Ellipsis]}. Only the existence of the \"0.\" is \
important, the strike price and ask can be anything, therefore the pattern \
match to apply is ",
 StyleBox["{_, 0., _}", "MB"],
 ". In the code below a rule containing this pattern is applied repeatedly:"
}], "Text",
 CellChangeTimes->{{3.469361931577375*^9, 3.469362223398526*^9}, {
  3.469367844296459*^9, 3.4693679280702763`*^9}, {3.469453850738896*^9, 
  3.469453896955511*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"puts", "=", 
  RowBox[{"puts", "//.", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"___", ",", 
      RowBox[{"{", 
       RowBox[{"_", ",", "0.", ",", "_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"_", ",", "0.", ",", "_"}], "}"}], ",", "x___"}], "}"}], 
    "\[Rule]", 
    RowBox[{"{", "x", "}"}]}]}]}]], "Input",
 CellChangeTimes->{{3.469290193149312*^9, 3.4692902201503887`*^9}, {
   3.469290259079558*^9, 3.46929029675766*^9}, {3.469290373025566*^9, 
   3.469290373480939*^9}, {3.469361854451056*^9, 3.469361857640592*^9}, {
   3.4693655392705317`*^9, 3.4693656902310247`*^9}, 3.469367603772766*^9, {
   3.469367940771265*^9, 3.469367946353116*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"375", ",", "0.`", ",", "0.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"400", ",", "0.05`", ",", "0.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"425", ",", "0.05`", ",", "0.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"450", ",", "0.05`", ",", "0.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"470", ",", "0.05`", ",", "0.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"475", ",", "0.05`", ",", "0.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"480", ",", "0.05`", ",", "0.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"490", ",", "0.05`", ",", "0.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"500", ",", "0.05`", ",", "0.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"510", ",", "0.05`", ",", "0.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"520", ",", "0.05`", ",", "0.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"525", ",", "0.05`", ",", "0.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"530", ",", "0.05`", ",", "0.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"540", ",", "0.05`", ",", "0.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"550", ",", "0.1`", ",", "0.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"560", ",", "0.05`", ",", "0.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"570", ",", "0.05`", ",", "0.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"575", ",", "0.05`", ",", "0.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"580", ",", "0.05`", ",", "0.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"585", ",", "0.1`", ",", "0.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"590", ",", "0.05`", ",", "0.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"595", ",", "0.05`", ",", "0.45`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"600", ",", "0.25`", ",", "0.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"605", ",", "0.1`", ",", "0.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"610", ",", "0.1`", ",", "0.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"615", ",", "0.1`", ",", "0.85`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"620", ",", "0.1`", ",", "0.85`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"625", ",", "0.4`", ",", "0.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"630", ",", "0.1`", ",", "0.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"635", ",", "0.1`", ",", "0.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"640", ",", "0.3`", ",", "1.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"645", ",", "0.1`", ",", "1.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"650", ",", "0.5`", ",", "1.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"655", ",", "0.2`", ",", "1.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"660", ",", "0.3`", ",", "1.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"665", ",", "0.2`", ",", "1.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"670", ",", "0.4`", ",", "1.45`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"675", ",", "0.5`", ",", "1.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"680", ",", "0.55`", ",", "1.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"690", ",", "0.7`", ",", "1.85`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"700", ",", "1.3`", ",", "1.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"710", ",", "1.1`", ",", "2.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"720", ",", "1.1`", ",", "3.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"725", ",", "2.`", ",", "3.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"730", ",", "1.4`", ",", "3.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"740", ",", "1.8`", ",", "4.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"750", ",", "3.2`", ",", "3.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"760", ",", "2.85`", ",", "5.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"770", ",", "4.`", ",", "5.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"775", ",", "3.9`", ",", "5.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"780", ",", "4.1`", ",", "6.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"790", ",", "4.9`", ",", "7.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"800", ",", "6.1`", ",", "7.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"805", ",", "6.4`", ",", "9.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"810", ",", "7.1`", ",", "9.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"815", ",", "7.5`", ",", "10.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"820", ",", "8.2`", ",", "10.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"825", ",", "8.9`", ",", "11.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"830", ",", "9.`", ",", "13.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"835", ",", "9.8`", ",", "13.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"840", ",", "10.6`", ",", "14.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"845", ",", "11.5`", ",", "15.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"850", ",", "13.5`", ",", "16.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"855", ",", "13.5`", ",", "17.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"860", ",", "14.5`", ",", "18.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"865", ",", "15.5`", ",", "19.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"870", ",", "17.1`", ",", "20.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"875", ",", "18.2`", ",", "22.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"880", ",", "19.2`", ",", "24.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"885", ",", "20.3`", ",", "25.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"890", ",", "22.1`", ",", "26.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"895", ",", "23.9`", ",", "29.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"900", ",", "25.5`", ",", "29.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"905", ",", "27.2`", ",", "32.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"910", ",", "29.2`", ",", "34.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"915", ",", "30.8`", ",", "36.3`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.469455097299428*^9, 3.469536496419429*^9, 
  3.4695365487059526`*^9, 3.470139173244232*^9}]
}, Open  ]],

Cell[TextData[{
 "\[OpenCurlyDoubleQuote]",
 StyleBox["select out-of-the-money call options with strike prices ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   RowBox[{">", " ", 
    SubscriptBox["K", 
     StyleBox["0",
      FontSlant->"Plain"]]}], TraditionalForm]],
  FontSlant->"Italic"],
 "\[CloseCurlyDoubleQuote]"
}], "Text",
 CellChangeTimes->{{3.469291357797076*^9, 3.46929136381182*^9}, {
  3.46936224291355*^9, 3.4693622510772467`*^9}}],

Cell["The same procedure is used for the call options.", "Text",
 CellChangeTimes->{{3.469362277937253*^9, 3.469362290136079*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"calls", "=", 
  RowBox[{"Select", "[", 
   RowBox[{
    RowBox[{"near", "\[LeftDoubleBracket]", 
     RowBox[{"All", ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "3"}], "}"}]}], "\[RightDoubleBracket]"}], 
    ",", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      ">", 
      SubscriptBox["\[ScriptCapitalK]", "0"]}], "&"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.469291375888198*^9, 3.469291378734775*^9}, {
  3.469362308689941*^9, 3.469362339323448*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"925", ",", "31.4`", ",", "35.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"930", ",", "31.`", ",", "33.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"935", ",", "26.`", ",", "31.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"940", ",", "26.`", ",", "29.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"945", ",", "21.6`", ",", "26.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"950", ",", "21.6`", ",", "24.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"955", ",", "17.2`", ",", "22.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"960", ",", "15.5`", ",", "19.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"965", ",", "13.9`", ",", "18.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"970", ",", "12.`", ",", "16.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"975", ",", "12.5`", ",", "14.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"980", ",", "9.3`", ",", "13.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"985", ",", "8.`", ",", "11.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"990", ",", "7.4`", ",", "9.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"995", ",", "6.4`", ",", "8.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1000", ",", "6.5`", ",", "7.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1005", ",", "4.4`", ",", "6.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1010", ",", "3.6`", ",", "6.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1015", ",", "3.1`", ",", "5.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1020", ",", "3.5`", ",", "4.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1025", ",", "2.`", ",", "4.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1030", ",", "1.6`", ",", "3.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1035", ",", "1.2`", ",", "3.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1040", ",", "1.25`", ",", "2.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1045", ",", "0.85`", ",", "2.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1050", ",", "1.3`", ",", "1.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1055", ",", "0.4`", ",", "1.65`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1060", ",", "0.9`", ",", "1.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1065", ",", "0.2`", ",", "1.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1070", ",", "0.15`", ",", "1.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1075", ",", "0.5`", ",", "1.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1080", ",", "0.4`", ",", "0.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1085", ",", "0.2`", ",", "0.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1090", ",", "0.3`", ",", "0.85`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1095", ",", "0.2`", ",", "0.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1100", ",", "0.3`", ",", "0.45`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1105", ",", "0.2`", ",", "0.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1110", ",", "0.2`", ",", "0.35`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1115", ",", "0.05`", ",", "0.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1120", ",", "0.05`", ",", "0.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1125", ",", "0.15`", ",", "0.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1130", ",", "0.05`", ",", "0.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1135", ",", "0.05`", ",", "0.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1140", ",", "0.05`", ",", "0.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1145", ",", "0.05`", ",", "0.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1150", ",", "0.05`", ",", "0.35`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1155", ",", "0.05`", ",", "0.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1160", ",", "0.05`", ",", "0.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1165", ",", "0.05`", ",", "0.35`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1170", ",", "0.05`", ",", "0.45`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1175", ",", "0.05`", ",", "0.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1180", ",", "0.05`", ",", "0.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1185", ",", "0.05`", ",", "0.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1190", ",", "0.05`", ",", "0.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1195", ",", "0.05`", ",", "1.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1200", ",", "0.05`", ",", "0.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1205", ",", "0.05`", ",", "1.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1210", ",", "0.05`", ",", "0.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1215", ",", "0.05`", ",", "0.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1220", ",", "0.05`", ",", "1.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1225", ",", "0.`", ",", "1.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1230", ",", "0.`", ",", "1.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1235", ",", "0.`", ",", "0.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1240", ",", "0.`", ",", "0.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1245", ",", "0.`", ",", "0.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1250", ",", "0.05`", ",", "0.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1255", ",", "0.`", ",", "1.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1260", ",", "0.`", ",", "1.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1265", ",", "0.`", ",", "1.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1270", ",", "0.`", ",", "0.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1275", ",", "0.`", ",", "0.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1280", ",", "0.`", ",", "0.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1285", ",", "0.`", ",", "0.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1290", ",", "0.`", ",", "0.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1295", ",", "0.`", ",", "0.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1300", ",", "0.`", ",", "0.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1305", ",", "0.`", ",", "0.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1310", ",", "0.`", ",", "0.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1315", ",", "0.`", ",", "0.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1320", ",", "0.`", ",", "0.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1325", ",", "0.`", ",", "0.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1330", ",", "0.`", ",", "0.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1335", ",", "0.`", ",", "0.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1340", ",", "0.`", ",", "0.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1345", ",", "0.`", ",", "0.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1350", ",", "0.`", ",", "0.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1355", ",", "0.`", ",", "0.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1360", ",", "0.`", ",", "0.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1365", ",", "0.`", ",", "0.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1370", ",", "0.`", ",", "0.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1375", ",", "0.`", ",", "0.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1380", ",", "0.`", ",", "0.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1385", ",", "0.`", ",", "0.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1390", ",", "0.`", ",", "0.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1395", ",", "0.`", ",", "0.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1400", ",", "0.`", ",", "0.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1405", ",", "0.`", ",", "0.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1410", ",", "0.`", ",", "0.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1415", ",", "0.`", ",", "0.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1420", ",", "0.`", ",", "0.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1425", ",", "0.`", ",", "0.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1430", ",", "0.`", ",", "0.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1435", ",", "0.`", ",", "0.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1440", ",", "0.`", ",", "0.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1445", ",", "0.`", ",", "0.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1450", ",", "0.`", ",", "0.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1460", ",", "0.`", ",", "0.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1470", ",", "0.`", ",", "0.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1475", ",", "0.`", ",", "0.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1480", ",", "0.`", ",", "0.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1490", ",", "0.`", ",", "1.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1500", ",", "0.`", ",", "0.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1650", ",", "0.`", ",", "1.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1700", ",", "0.`", ",", "1.`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.469455097334433*^9, 3.469536496561771*^9, 
  3.4695365487608023`*^9, 3.470139173344997*^9}]
}, Open  ]],

Cell[TextData[{
 "\[OpenCurlyDoubleQuote]",
 StyleBox["\[Ellipsis] once two consecutive call options are found to have \
zero bid prices, no calls with higher strikes are considered",
  FontSlant->"Italic"],
 "\[CloseCurlyDoubleQuote]"
}], "Text",
 CellChangeTimes->{{3.469291420934465*^9, 3.469291426253394*^9}, {
   3.469291507504448*^9, 3.469291509319254*^9}, 3.469453922917721*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"calls", "=", 
  RowBox[{"calls", "//.", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x___", ",", 
      RowBox[{"{", 
       RowBox[{"_", ",", "0.", ",", "_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"_", ",", "0.", ",", "_"}], "}"}], ",", "___"}], "}"}], 
    "\[Rule]", 
    RowBox[{"{", "x", "}"}]}]}]}]], "Input",
 CellChangeTimes->{{3.469290193149312*^9, 3.4692902201503887`*^9}, {
  3.469290259079558*^9, 3.46929029675766*^9}, {3.469290373025566*^9, 
  3.469290373480939*^9}, {3.469291438857647*^9, 3.469291465210216*^9}, {
  3.469362329819704*^9, 3.469362332339251*^9}, {3.469367618163692*^9, 
  3.4693676184980793`*^9}, {3.469367957475841*^9, 3.4693679585050173`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"925", ",", "31.4`", ",", "35.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"930", ",", "31.`", ",", "33.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"935", ",", "26.`", ",", "31.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"940", ",", "26.`", ",", "29.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"945", ",", "21.6`", ",", "26.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"950", ",", "21.6`", ",", "24.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"955", ",", "17.2`", ",", "22.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"960", ",", "15.5`", ",", "19.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"965", ",", "13.9`", ",", "18.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"970", ",", "12.`", ",", "16.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"975", ",", "12.5`", ",", "14.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"980", ",", "9.3`", ",", "13.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"985", ",", "8.`", ",", "11.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"990", ",", "7.4`", ",", "9.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"995", ",", "6.4`", ",", "8.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1000", ",", "6.5`", ",", "7.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1005", ",", "4.4`", ",", "6.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1010", ",", "3.6`", ",", "6.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1015", ",", "3.1`", ",", "5.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1020", ",", "3.5`", ",", "4.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1025", ",", "2.`", ",", "4.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1030", ",", "1.6`", ",", "3.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1035", ",", "1.2`", ",", "3.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1040", ",", "1.25`", ",", "2.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1045", ",", "0.85`", ",", "2.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1050", ",", "1.3`", ",", "1.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1055", ",", "0.4`", ",", "1.65`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1060", ",", "0.9`", ",", "1.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1065", ",", "0.2`", ",", "1.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1070", ",", "0.15`", ",", "1.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1075", ",", "0.5`", ",", "1.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1080", ",", "0.4`", ",", "0.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1085", ",", "0.2`", ",", "0.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1090", ",", "0.3`", ",", "0.85`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1095", ",", "0.2`", ",", "0.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1100", ",", "0.3`", ",", "0.45`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1105", ",", "0.2`", ",", "0.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1110", ",", "0.2`", ",", "0.35`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1115", ",", "0.05`", ",", "0.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1120", ",", "0.05`", ",", "0.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1125", ",", "0.15`", ",", "0.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1130", ",", "0.05`", ",", "0.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1135", ",", "0.05`", ",", "0.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1140", ",", "0.05`", ",", "0.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1145", ",", "0.05`", ",", "0.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1150", ",", "0.05`", ",", "0.35`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1155", ",", "0.05`", ",", "0.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1160", ",", "0.05`", ",", "0.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1165", ",", "0.05`", ",", "0.35`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1170", ",", "0.05`", ",", "0.45`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1175", ",", "0.05`", ",", "0.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1180", ",", "0.05`", ",", "0.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1185", ",", "0.05`", ",", "0.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1190", ",", "0.05`", ",", "0.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1195", ",", "0.05`", ",", "1.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1200", ",", "0.05`", ",", "0.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1205", ",", "0.05`", ",", "1.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1210", ",", "0.05`", ",", "0.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1215", ",", "0.05`", ",", "0.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1220", ",", "0.05`", ",", "1.`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.469455097370102*^9, 3.4695364966355553`*^9, 
  3.4695365488268642`*^9, 3.470139173444079*^9}]
}, Open  ]],

Cell[TextData[{
 "\[OpenCurlyDoubleQuote]",
 StyleBox["Finally, select both the put and call with strike price ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["K", 
    StyleBox["0",
     FontSlant->"Plain"]], TraditionalForm]],
  FontSlant->"Italic"],
 StyleBox[". \[Ellipsis] The ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["K", 
    StyleBox["0",
     FontSlant->"Plain"]], TraditionalForm]],
  FontSlant->"Italic"],
 StyleBox[" put and call prices are averaged to produce a single value.",
  FontSlant->"Italic"],
 "\[CloseCurlyDoubleQuote]"
}], "Text",
 CellChangeTimes->{{3.46936257911615*^9, 3.469362582735239*^9}, {
   3.4693626288770943`*^9, 3.4693626365202637`*^9}, {3.4693628686216717`*^9, 
   3.469362874646048*^9}, {3.469453958021837*^9, 3.469453971975795*^9}, 
   3.4694549091257668`*^9}],

Cell[TextData[{
 "The function ",
 StyleBox["Select", "MB"],
 " can be used to pick out the element at ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["K", "0"], TraditionalForm]]],
 ":"
}], "Text",
 CellChangeTimes->{{3.469362657000369*^9, 3.469362660616436*^9}, {
  3.469362861142592*^9, 3.4693628655250187`*^9}, {3.469362898945073*^9, 
  3.469362907634816*^9}, {3.469453950741744*^9, 3.4694539685658712`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Select", "[", 
  RowBox[{"near", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
     "\[Equal]", 
     SubscriptBox["\[ScriptCapitalK]", "0"]}], "&"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"920", ",", "35.2`", ",", "39.1`", ",", "35.2`", ",", "38.1`"}], 
   "}"}], "}"}]], "Output",
 CellChangeTimes->{3.4694550973980513`*^9, 3.469536496728386*^9, 
  3.469536548875908*^9, 3.470139173521297*^9}]
}, Open  ]],

Cell[TextData[{
 "Combining this with a rule replacement allows the output to be of the form ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     StyleBox[
      RowBox[{"strike", " ", "price"}],
      FontSlant->"Italic"], ",", 
     StyleBox[
      RowBox[{"average", " ", "of", " ", "puts"}],
      FontSlant->"Italic"], ",", 
     StyleBox[
      RowBox[{"average", " ", "of", " ", "calls"}],
      FontSlant->"Italic"]}], "}"}], TraditionalForm]]],
 ":"
}], "Text",
 CellChangeTimes->{{3.469362918687914*^9, 3.469362979242277*^9}, {
  3.469453996080196*^9, 3.4694540092622843`*^9}, {3.470139390039199*^9, 
  3.4701393949718924`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"K0", "=", 
  RowBox[{
   RowBox[{"Select", "[", 
    RowBox[{"near", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
       "\[Equal]", 
       SubscriptBox["\[ScriptCapitalK]", "0"]}], "&"}]}], "]"}], "/.", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "x5_"}], "}"}], 
    "\[RuleDelayed]", 
    RowBox[{"{", 
     RowBox[{"x1", ",", 
      RowBox[{"Mean", "@", 
       RowBox[{"{", 
        RowBox[{"x2", ",", "x3"}], "}"}]}], ",", 
      RowBox[{"Mean", "@", 
       RowBox[{"{", 
        RowBox[{"x4", ",", "x5"}], "}"}]}]}], "}"}]}]}]}]], "Input",
 CellChangeTimes->{{3.469291891270482*^9, 3.469291916241807*^9}, {
  3.469292152544788*^9, 3.46929219864242*^9}, {3.4692922847476397`*^9, 
  3.469292288777935*^9}, {3.469362418636211*^9, 3.469362421628825*^9}, {
  3.469362652397532*^9, 3.469362808222673*^9}, {3.469362842072781*^9, 
  3.469362842401237*^9}, {3.469362956332757*^9, 3.469362970937772*^9}, {
  3.469363017709326*^9, 3.469363018852459*^9}, {3.469363161483762*^9, 
  3.4693631993705072`*^9}, {3.469454026067833*^9, 3.469454027482156*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"920", ",", "37.150000000000006`", ",", "36.650000000000006`"}], 
   "}"}], "}"}]], "Output",
 CellChangeTimes->{3.4694550974312477`*^9, 3.469536496827332*^9, 
  3.469536548926017*^9, 3.470139173608337*^9}]
}, Open  ]],

Cell[TextData[{
 "As an alternative the function ",
 StyleBox["Cases", "MB"],
 " could have been used:"
}], "Text",
 CellChangeTimes->{{3.4694540313022537`*^9, 3.469454040878188*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Cases", "[", 
  RowBox[{"near", ",", 
   RowBox[{
    RowBox[{"x_", "/;", 
     RowBox[{
      RowBox[{"x", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      "\[Equal]", 
      SubscriptBox["\[ScriptCapitalK]", "0"]}]}], "\[RuleDelayed]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      ",", 
      RowBox[{"Mean", "[", 
       RowBox[{"x", "\[LeftDoubleBracket]", 
        RowBox[{"{", 
         RowBox[{"2", ",", "3"}], "}"}], "\[RightDoubleBracket]"}], "]"}], 
      ",", 
      RowBox[{"Mean", "[", 
       RowBox[{"x", "\[LeftDoubleBracket]", 
        RowBox[{"{", 
         RowBox[{"4", ",", "5"}], "}"}], "\[RightDoubleBracket]"}], "]"}]}], 
     "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.469454046106903*^9, 3.469454075841681*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"920", ",", "37.150000000000006`", ",", "36.650000000000006`"}], 
   "}"}], "}"}]], "Output",
 CellChangeTimes->{3.469455097464158*^9, 3.469536496995026*^9, 
  3.4695365489753637`*^9, 3.470139173670631*^9}]
}, Open  ]],

Cell["\<\
Join the data together and remove any remaining cases with a bid price of \
zero:\
\>", "Text",
 CellChangeTimes->{{3.469363264384666*^9, 3.46936327115025*^9}, {
  3.4693676367213097`*^9, 3.4693676757447157`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"combinedList", "=", 
  RowBox[{"DeleteCases", "[", 
   RowBox[{
    RowBox[{"Join", "[", 
     RowBox[{"puts", ",", "K0", ",", "calls"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"_", ",", "0.", ",", "_"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.469292296070223*^9, 3.469292331715446*^9}, {
  3.469363003491149*^9, 3.469363027586382*^9}, {3.469363257218004*^9, 
  3.469363258647561*^9}, {3.469367678642886*^9, 3.4693677010150623`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"400", ",", "0.05`", ",", "0.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"425", ",", "0.05`", ",", "0.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"450", ",", "0.05`", ",", "0.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"470", ",", "0.05`", ",", "0.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"475", ",", "0.05`", ",", "0.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"480", ",", "0.05`", ",", "0.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"490", ",", "0.05`", ",", "0.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"500", ",", "0.05`", ",", "0.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"510", ",", "0.05`", ",", "0.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"520", ",", "0.05`", ",", "0.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"525", ",", "0.05`", ",", "0.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"530", ",", "0.05`", ",", "0.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"540", ",", "0.05`", ",", "0.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"550", ",", "0.1`", ",", "0.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"560", ",", "0.05`", ",", "0.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"570", ",", "0.05`", ",", "0.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"575", ",", "0.05`", ",", "0.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"580", ",", "0.05`", ",", "0.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"585", ",", "0.1`", ",", "0.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"590", ",", "0.05`", ",", "0.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"595", ",", "0.05`", ",", "0.45`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"600", ",", "0.25`", ",", "0.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"605", ",", "0.1`", ",", "0.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"610", ",", "0.1`", ",", "0.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"615", ",", "0.1`", ",", "0.85`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"620", ",", "0.1`", ",", "0.85`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"625", ",", "0.4`", ",", "0.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"630", ",", "0.1`", ",", "0.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"635", ",", "0.1`", ",", "0.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"640", ",", "0.3`", ",", "1.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"645", ",", "0.1`", ",", "1.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"650", ",", "0.5`", ",", "1.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"655", ",", "0.2`", ",", "1.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"660", ",", "0.3`", ",", "1.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"665", ",", "0.2`", ",", "1.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"670", ",", "0.4`", ",", "1.45`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"675", ",", "0.5`", ",", "1.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"680", ",", "0.55`", ",", "1.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"690", ",", "0.7`", ",", "1.85`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"700", ",", "1.3`", ",", "1.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"710", ",", "1.1`", ",", "2.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"720", ",", "1.1`", ",", "3.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"725", ",", "2.`", ",", "3.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"730", ",", "1.4`", ",", "3.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"740", ",", "1.8`", ",", "4.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"750", ",", "3.2`", ",", "3.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"760", ",", "2.85`", ",", "5.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"770", ",", "4.`", ",", "5.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"775", ",", "3.9`", ",", "5.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"780", ",", "4.1`", ",", "6.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"790", ",", "4.9`", ",", "7.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"800", ",", "6.1`", ",", "7.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"805", ",", "6.4`", ",", "9.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"810", ",", "7.1`", ",", "9.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"815", ",", "7.5`", ",", "10.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"820", ",", "8.2`", ",", "10.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"825", ",", "8.9`", ",", "11.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"830", ",", "9.`", ",", "13.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"835", ",", "9.8`", ",", "13.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"840", ",", "10.6`", ",", "14.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"845", ",", "11.5`", ",", "15.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"850", ",", "13.5`", ",", "16.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"855", ",", "13.5`", ",", "17.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"860", ",", "14.5`", ",", "18.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"865", ",", "15.5`", ",", "19.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"870", ",", "17.1`", ",", "20.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"875", ",", "18.2`", ",", "22.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"880", ",", "19.2`", ",", "24.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"885", ",", "20.3`", ",", "25.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"890", ",", "22.1`", ",", "26.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"895", ",", "23.9`", ",", "29.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"900", ",", "25.5`", ",", "29.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"905", ",", "27.2`", ",", "32.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"910", ",", "29.2`", ",", "34.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"915", ",", "30.8`", ",", "36.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"920", ",", "37.150000000000006`", ",", "36.650000000000006`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"925", ",", "31.4`", ",", "35.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"930", ",", "31.`", ",", "33.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"935", ",", "26.`", ",", "31.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"940", ",", "26.`", ",", "29.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"945", ",", "21.6`", ",", "26.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"950", ",", "21.6`", ",", "24.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"955", ",", "17.2`", ",", "22.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"960", ",", "15.5`", ",", "19.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"965", ",", "13.9`", ",", "18.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"970", ",", "12.`", ",", "16.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"975", ",", "12.5`", ",", "14.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"980", ",", "9.3`", ",", "13.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"985", ",", "8.`", ",", "11.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"990", ",", "7.4`", ",", "9.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"995", ",", "6.4`", ",", "8.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1000", ",", "6.5`", ",", "7.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1005", ",", "4.4`", ",", "6.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1010", ",", "3.6`", ",", "6.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1015", ",", "3.1`", ",", "5.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1020", ",", "3.5`", ",", "4.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1025", ",", "2.`", ",", "4.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1030", ",", "1.6`", ",", "3.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1035", ",", "1.2`", ",", "3.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1040", ",", "1.25`", ",", "2.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1045", ",", "0.85`", ",", "2.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1050", ",", "1.3`", ",", "1.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1055", ",", "0.4`", ",", "1.65`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1060", ",", "0.9`", ",", "1.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1065", ",", "0.2`", ",", "1.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1070", ",", "0.15`", ",", "1.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1075", ",", "0.5`", ",", "1.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1080", ",", "0.4`", ",", "0.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1085", ",", "0.2`", ",", "0.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1090", ",", "0.3`", ",", "0.85`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1095", ",", "0.2`", ",", "0.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1100", ",", "0.3`", ",", "0.45`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1105", ",", "0.2`", ",", "0.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1110", ",", "0.2`", ",", "0.35`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1115", ",", "0.05`", ",", "0.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1120", ",", "0.05`", ",", "0.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1125", ",", "0.15`", ",", "0.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1130", ",", "0.05`", ",", "0.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1135", ",", "0.05`", ",", "0.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1140", ",", "0.05`", ",", "0.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1145", ",", "0.05`", ",", "0.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1150", ",", "0.05`", ",", "0.35`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1155", ",", "0.05`", ",", "0.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1160", ",", "0.05`", ",", "0.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1165", ",", "0.05`", ",", "0.35`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1170", ",", "0.05`", ",", "0.45`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1175", ",", "0.05`", ",", "0.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1180", ",", "0.05`", ",", "0.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1185", ",", "0.05`", ",", "0.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1190", ",", "0.05`", ",", "0.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1195", ",", "0.05`", ",", "1.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1200", ",", "0.05`", ",", "0.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1205", ",", "0.05`", ",", "1.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1210", ",", "0.05`", ",", "0.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1215", ",", "0.05`", ",", "0.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1220", ",", "0.05`", ",", "1.`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.4694550975009737`*^9, 3.469536497078171*^9, 
  3.469536549028318*^9, 3.4701391739077473`*^9}]
}, Open  ]],

Cell["Finally take the mean of the bid and ask values:", "Text",
 CellChangeTimes->{{3.469363280895811*^9, 3.469363292942732*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"#1", ",", 
     RowBox[{"0.5", "*", 
      RowBox[{"(", 
       RowBox[{"#2", "+", "#3"}], ")"}]}]}], "}"}], "&"}], "@@@", 
  "combinedList"}]], "Input",
 CellChangeTimes->{{3.469292225673993*^9, 3.469292236784821*^9}, 
   3.4692922791161337`*^9, {3.469292341149479*^9, 3.469292370036023*^9}, {
   3.469294122998053*^9, 3.469294123746833*^9}, {3.469363303538095*^9, 
   3.4693633048089952`*^9}, 3.469363486301692*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"400", ",", "0.125`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"425", ",", "0.125`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"450", ",", "0.125`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"470", ",", "0.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"475", ",", "0.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"480", ",", "0.175`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"490", ",", "0.42500000000000004`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"500", ",", "0.175`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"510", ",", "0.225`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"520", ",", "0.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"525", ",", "0.42500000000000004`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"530", ",", "0.42500000000000004`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"540", ",", "0.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"550", ",", "0.15000000000000002`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"560", ",", "0.375`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"570", ",", "0.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"575", ",", "0.225`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"580", ",", "0.42500000000000004`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"585", ",", "0.425`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"590", ",", "0.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"595", ",", "0.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"600", ",", "0.375`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"605", ",", "0.45`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"610", ",", "0.45`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"615", ",", "0.475`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"620", ",", "0.475`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"625", ",", "0.65`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"630", ",", "0.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"635", ",", "0.525`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"640", ",", "0.675`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"645", ",", "0.6000000000000001`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"650", ",", "0.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"655", ",", "0.725`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"660", ",", "0.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"665", ",", "0.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"670", ",", "0.925`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"675", ",", "1.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"680", ",", "1.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"690", ",", "1.275`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"700", ",", "1.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"710", ",", "1.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"720", ",", "2.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"725", ",", "2.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"730", ",", "2.45`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"740", ",", "2.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"750", ",", "3.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"760", ",", "3.925`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"770", ",", "4.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"775", ",", "4.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"780", ",", "5.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"790", ",", "6.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"800", ",", "6.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"805", ",", "7.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"810", ",", "8.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"815", ",", "8.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"820", ",", "9.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"825", ",", "10.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"830", ",", "11.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"835", ",", "11.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"840", ",", "12.45`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"845", ",", "13.35`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"850", ",", "14.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"855", ",", "15.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"860", ",", "16.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"865", ",", "17.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"870", ",", "19.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"875", ",", "20.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"880", ",", "21.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"885", ",", "22.85`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"890", ",", "24.450000000000003`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"895", ",", "26.45`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"900", ",", "27.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"905", ",", "29.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"910", ",", "31.700000000000003`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"915", ",", "33.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"920", ",", "36.900000000000006`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"925", ",", "33.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"930", ",", "32.45`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"935", ",", "28.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"940", ",", "27.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"945", ",", "24.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"950", ",", "23.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"955", ",", "19.85`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"960", ",", "17.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"965", ",", "15.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"970", ",", "14.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"975", ",", "13.65`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"980", ",", "11.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"985", ",", "9.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"990", ",", "8.65`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"995", ",", "7.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1000", ",", "7.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1005", ",", "5.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1010", ",", "4.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1015", ",", "4.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1020", ",", "4.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1025", ",", "3.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1030", ",", "2.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1035", ",", "2.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1040", ",", "1.875`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1045", ",", "1.475`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1050", ",", "1.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1055", ",", "1.025`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1060", ",", "1.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1065", ",", "0.725`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1070", ",", "0.6499999999999999`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1075", ",", "0.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1080", ",", "0.675`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1085", ",", "0.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1090", ",", "0.575`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1095", ",", "0.475`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1100", ",", "0.375`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1105", ",", "0.475`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1110", ",", "0.275`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1115", ",", "0.42500000000000004`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1120", ",", "0.275`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1125", ",", "0.325`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1130", ",", "0.47500000000000003`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1135", ",", "0.47500000000000003`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1140", ",", "0.375`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1145", ",", "0.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1150", ",", "0.19999999999999998`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1155", ",", "0.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1160", ",", "0.275`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1165", ",", "0.19999999999999998`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1170", ",", "0.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1175", ",", "0.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1180", ",", "0.42500000000000004`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1185", ",", "0.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1190", ",", "0.275`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1195", ",", "0.525`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1200", ",", "0.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1205", ",", "0.525`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1210", ",", "0.275`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1215", ",", "0.275`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1220", ",", "0.525`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.46945509753372*^9, 3.469536497261376*^9, 
  3.4695365490940332`*^9, 3.470139173991332*^9}]
}, Open  ]],

Cell[TextData[{
 "All these steps can be combined into a single function to process the \
option data. In the code below variables are localized within a ",
 StyleBox["Module", "MB"],
 "."
}], "Text",
 CellChangeTimes->{{3.469364544988656*^9, 3.469364657245943*^9}, 
   3.469364755170267*^9, {3.469454137443411*^9, 3.469454137624854*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", "processOptionData", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"processOptionData", "[", 
   RowBox[{"data_", ",", "rate_", ",", "time_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "tmp1", ",", "FData", ",", "\[ScriptCapitalF]", ",", "\[ScriptCapitalK]",
       ",", "puts", ",", "calls", ",", "K0", ",", "combinedList"}], "}"}], 
    ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"tmp1", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"#1", ",", 
          RowBox[{"Abs", "[", 
           RowBox[{
            RowBox[{"0.5", "*", 
             RowBox[{"(", 
              RowBox[{"#2", "+", "#3"}], ")"}]}], "-", 
            RowBox[{"0.5", "*", 
             RowBox[{"(", 
              RowBox[{"#4", "+", "#5"}], ")"}]}]}], "]"}]}], "}"}], "&"}], "@@@",
        "data"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"FData", "=", 
      RowBox[{"First", "@", 
       RowBox[{"Sort", "[", 
        RowBox[{"tmp1", ",", 
         RowBox[{
          RowBox[{
           RowBox[{
           "#1", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], "<", 
           
           RowBox[{
           "#2", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
          "&"}]}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"\[ScriptCapitalF]", "=", 
      RowBox[{
       RowBox[{
       "FData", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "+", 
       RowBox[{
        RowBox[{
        "FData", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], "*", 
        
        RowBox[{"Exp", "[", 
         RowBox[{"rate", "*", "time"}], "]"}]}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"\[ScriptCapitalK]", "=", 
      RowBox[{"Max", "[", 
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{"tmp1", "\[LeftDoubleBracket]", 
          RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
         RowBox[{
          RowBox[{"#", "<", "\[ScriptCapitalF]"}], "&"}]}], "]"}], "]"}]}], 
     ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"puts", "=", 
      RowBox[{"Select", "[", 
       RowBox[{
        RowBox[{"data", "\[LeftDoubleBracket]", 
         RowBox[{"All", ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "4", ",", "5"}], "}"}]}], 
         "\[RightDoubleBracket]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
           "<", "\[ScriptCapitalK]"}], "&"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"puts", "=", 
      RowBox[{"puts", "//.", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"___", ",", 
          RowBox[{"{", 
           RowBox[{"_", ",", "0.", ",", "_"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"_", ",", "0.", ",", "_"}], "}"}], ",", "x___"}], "}"}], 
        "\[RuleDelayed]", 
        RowBox[{"{", "x", "}"}]}]}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"calls", "=", 
      RowBox[{"Select", "[", 
       RowBox[{
        RowBox[{"data", "\[LeftDoubleBracket]", 
         RowBox[{"All", ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "2", ",", "3"}], "}"}]}], 
         "\[RightDoubleBracket]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
           ">", "\[ScriptCapitalK]"}], "&"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"calls", "=", 
      RowBox[{"calls", "//.", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"x___", ",", 
          RowBox[{"{", 
           RowBox[{"_", ",", "0.", ",", "_"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"_", ",", "0.", ",", "_"}], "}"}], ",", "___"}], "}"}], 
        "\[RuleDelayed]", 
        RowBox[{"{", "x", "}"}]}]}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"K0", "=", 
      RowBox[{
       RowBox[{"Select", "[", 
        RowBox[{"data", ",", 
         RowBox[{
          RowBox[{
           RowBox[{
           "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
           "\[Equal]", "\[ScriptCapitalK]"}], "&"}]}], "]"}], "/.", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "x5_"}], 
         "}"}], "\[RuleDelayed]", 
        RowBox[{"{", 
         RowBox[{"x1", ",", 
          RowBox[{"Mean", "@", 
           RowBox[{"{", 
            RowBox[{"x2", ",", "x3"}], "}"}]}], ",", 
          RowBox[{"Mean", "@", 
           RowBox[{"{", 
            RowBox[{"x4", ",", "x5"}], "}"}]}]}], "}"}]}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"combinedList", "=", 
      RowBox[{"DeleteCases", "[", 
       RowBox[{
        RowBox[{"Join", "[", 
         RowBox[{"puts", ",", "K0", ",", "calls"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"_", ",", "0.", ",", "_"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"#1", ",", 
         RowBox[{"0.5", "*", 
          RowBox[{"(", 
           RowBox[{"#2", "+", "#3"}], ")"}]}]}], "}"}], "&"}], "@@@", 
      "combinedList"}]}]}], "\[IndentingNewLine]", "]"}]}]}], "Input",
 CellChangeTimes->{{3.469363364532826*^9, 3.469363483263266*^9}, {
  3.469364295809856*^9, 3.469364487080785*^9}, {3.469367722122272*^9, 
  3.469367743906396*^9}, {3.470139438622301*^9, 3.4701394508849363`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"processOptionData", "[", 
  RowBox[{"near", ",", "0.0038", ",", 
   SubscriptBox["\[ScriptCapitalT]", "1"]}], "]"}]], "Input",
 CellChangeTimes->{
  3.469365097442775*^9, {3.4693651495740767`*^9, 3.4693651514022512`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"400", ",", "0.125`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"425", ",", "0.125`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"450", ",", "0.125`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"470", ",", "0.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"475", ",", "0.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"480", ",", "0.175`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"490", ",", "0.42500000000000004`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"500", ",", "0.175`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"510", ",", "0.225`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"520", ",", "0.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"525", ",", "0.42500000000000004`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"530", ",", "0.42500000000000004`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"540", ",", "0.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"550", ",", "0.15000000000000002`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"560", ",", "0.375`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"570", ",", "0.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"575", ",", "0.225`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"580", ",", "0.42500000000000004`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"585", ",", "0.425`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"590", ",", "0.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"595", ",", "0.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"600", ",", "0.375`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"605", ",", "0.45`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"610", ",", "0.45`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"615", ",", "0.475`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"620", ",", "0.475`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"625", ",", "0.65`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"630", ",", "0.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"635", ",", "0.525`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"640", ",", "0.675`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"645", ",", "0.6000000000000001`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"650", ",", "0.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"655", ",", "0.725`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"660", ",", "0.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"665", ",", "0.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"670", ",", "0.925`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"675", ",", "1.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"680", ",", "1.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"690", ",", "1.275`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"700", ",", "1.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"710", ",", "1.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"720", ",", "2.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"725", ",", "2.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"730", ",", "2.45`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"740", ",", "2.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"750", ",", "3.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"760", ",", "3.925`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"770", ",", "4.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"775", ",", "4.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"780", ",", "5.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"790", ",", "6.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"800", ",", "6.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"805", ",", "7.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"810", ",", "8.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"815", ",", "8.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"820", ",", "9.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"825", ",", "10.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"830", ",", "11.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"835", ",", "11.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"840", ",", "12.45`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"845", ",", "13.35`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"850", ",", "14.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"855", ",", "15.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"860", ",", "16.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"865", ",", "17.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"870", ",", "19.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"875", ",", "20.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"880", ",", "21.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"885", ",", "22.85`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"890", ",", "24.450000000000003`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"895", ",", "26.45`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"900", ",", "27.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"905", ",", "29.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"910", ",", "31.700000000000003`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"915", ",", "33.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"920", ",", "36.900000000000006`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"925", ",", "33.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"930", ",", "32.45`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"935", ",", "28.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"940", ",", "27.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"945", ",", "24.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"950", ",", "23.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"955", ",", "19.85`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"960", ",", "17.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"965", ",", "15.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"970", ",", "14.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"975", ",", "13.65`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"980", ",", "11.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"985", ",", "9.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"990", ",", "8.65`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"995", ",", "7.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1000", ",", "7.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1005", ",", "5.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1010", ",", "4.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1015", ",", "4.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1020", ",", "4.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1025", ",", "3.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1030", ",", "2.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1035", ",", "2.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1040", ",", "1.875`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1045", ",", "1.475`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1050", ",", "1.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1055", ",", "1.025`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1060", ",", "1.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1065", ",", "0.725`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1070", ",", "0.6499999999999999`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1075", ",", "0.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1080", ",", "0.675`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1085", ",", "0.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1090", ",", "0.575`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1095", ",", "0.475`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1100", ",", "0.375`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1105", ",", "0.475`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1110", ",", "0.275`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1115", ",", "0.42500000000000004`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1120", ",", "0.275`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1125", ",", "0.325`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1130", ",", "0.47500000000000003`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1135", ",", "0.47500000000000003`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1140", ",", "0.375`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1145", ",", "0.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1150", ",", "0.19999999999999998`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1155", ",", "0.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1160", ",", "0.275`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1165", ",", "0.19999999999999998`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1170", ",", "0.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1175", ",", "0.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1180", ",", "0.42500000000000004`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1185", ",", "0.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1190", ",", "0.275`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1195", ",", "0.525`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1200", ",", "0.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1205", ",", "0.525`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1210", ",", "0.275`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1215", ",", "0.275`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1220", ",", "0.525`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.469455097650185*^9, 3.4695364977993317`*^9, 
  3.46953654918919*^9, 3.470139174127635*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"processOptionData", "[", 
  RowBox[{"next", ",", "0.0038", ",", 
   SubscriptBox["\[ScriptCapitalT]", "2"]}], "]"}]], "Input",
 CellChangeTimes->{{3.4693652068372183`*^9, 3.469365210411558*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"200", ",", "0.325`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"300", ",", "0.30000000000000004`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"350", ",", "0.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"375", ",", "0.35`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"400", ",", "0.525`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"450", ",", "0.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"475", ",", "1.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"500", ",", "1.675`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"525", ",", "1.875`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"550", ",", "2.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"575", ",", "3.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"600", ",", "4.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"610", ",", "4.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"615", ",", "5.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"620", ",", "5.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"625", ",", "5.550000000000001`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"630", ",", "5.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"635", ",", "6.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"640", ",", "6.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"650", ",", "6.949999999999999`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"660", ",", "7.65`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"670", ",", "8.45`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"675", ",", "8.65`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"680", ",", "9.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"690", ",", "10.100000000000001`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"700", ",", "10.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"710", ",", "11.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"720", ",", "12.85`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"725", ",", "13.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"730", ",", "14.149999999999999`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"740", ",", "15.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"750", ",", "16.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"760", ",", "18.049999999999997`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"770", ",", "19.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"775", ",", "20.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"780", ",", "21.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"790", ",", "23.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"800", ",", "25.35`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"805", ",", "26.299999999999997`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"810", ",", "27.35`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"815", ",", "28.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"820", ",", "29.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"825", ",", "30.549999999999997`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"830", ",", "31.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"835", ",", "32.85`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"840", ",", "34.35`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"845", ",", "35.45`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"850", ",", "36.85`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"855", ",", "37.45`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"860", ",", "39.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"865", ",", "41.150000000000006`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"870", ",", "42.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"875", ",", "44.400000000000006`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"880", ",", "46.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"885", ",", "47.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"890", ",", "49.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"895", ",", "51.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"900", ",", "52.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"905", ",", "54.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"910", ",", "56.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"915", ",", "58.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"920", ",", "61.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"925", ",", "58.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"930", ",", "55.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"935", ",", "53.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"940", ",", "50.150000000000006`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"945", ",", "48.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"950", ",", "46.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"955", ",", "42.849999999999994`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"960", ",", "40.650000000000006`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"965", ",", "38.150000000000006`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"970", ",", "36.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"975", ",", "34.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"980", ",", "31.45`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"985", ",", "29.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"990", ",", "27.85`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"995", ",", "25.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1000", ",", "24.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1005", ",", "22.35`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1010", ",", "20.85`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1015", ",", "19.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1020", ",", "18.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1025", ",", "16.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1030", ",", "15.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1035", ",", "13.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1040", ",", "12.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1045", ",", "11.45`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1050", ",", "11.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1055", ",", "9.35`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1060", ",", "9.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1065", ",", "7.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1070", ",", "6.85`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1075", ",", "6.35`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1080", ",", "5.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1085", ",", "5.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1090", ",", "4.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1095", ",", "3.9000000000000004`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1100", ",", "3.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1105", ",", "3.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1110", ",", "2.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1115", ",", "2.4749999999999996`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1120", ",", "2.225`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1125", ",", "2.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1130", ",", "1.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1135", ",", "1.2999999999999998`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1140", ",", "1.375`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1145", ",", "1.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1150", ",", "0.825`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1155", ",", "0.725`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1160", ",", "0.6000000000000001`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.469455097683301*^9, 3.469536498281931*^9, 
  3.469536549244906*^9, 3.4701391741835527`*^9}]
}, Open  ]],

Cell["\<\
A user may prefer to combine some of these steps and also include the \
expiration time calculation in the function:\
\>", "Text",
 CellChangeTimes->{{3.469364759738179*^9, 3.469364811089368*^9}, {
  3.469364893100625*^9, 3.46936490209914*^9}, {3.469454164018713*^9, 
  3.4694541755535183`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", "processOptionData1", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"processOptionData1", "[", 
   RowBox[{"data_", ",", "rate_", ",", "days_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "now", ",", "term", ",", "secondsPerYear", ",", "\[ScriptCapitalT]", ",",
       "tmp1", ",", "FData", ",", "\[ScriptCapitalF]", ",", 
      "\[ScriptCapitalK]", ",", "puts", ",", "calls", ",", "K0"}], "}"}], ",",
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{"calculate", " ", "expiration", " ", "time"}], " ", "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"now", "=", 
      RowBox[{"DateList", "[", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"term", "=", 
      RowBox[{"DatePlus", "[", 
       RowBox[{"now", ",", "days"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"secondsPerYear", "=", 
      RowBox[{"N", "[", 
       RowBox[{"365", "*", "24", "*", "60", "*", "60"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"\[ScriptCapitalT]", "=", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"AbsoluteTime", "[", "term", "]"}], "-", 
         RowBox[{"AbsoluteTime", "[", "now", "]"}]}], ")"}], "/", 
       "secondsPerYear"}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"process", " ", "data"}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"tmp1", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"#1", ",", 
          RowBox[{"Abs", "[", 
           RowBox[{
            RowBox[{"0.5", "*", 
             RowBox[{"(", 
              RowBox[{"#2", "+", "#3"}], ")"}]}], "-", 
            RowBox[{"0.5", "*", 
             RowBox[{"(", 
              RowBox[{"#4", "+", "#5"}], ")"}]}]}], "]"}]}], "}"}], "&"}], "@@@",
        "data"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"FData", "=", 
      RowBox[{"First", "@", 
       RowBox[{"Sort", "[", 
        RowBox[{"tmp1", ",", 
         RowBox[{
          RowBox[{
           RowBox[{
           "#1", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], "<", 
           
           RowBox[{
           "#2", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
          "&"}]}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"\[ScriptCapitalF]", "=", 
      RowBox[{
       RowBox[{
       "FData", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "+", 
       RowBox[{
        RowBox[{
        "FData", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], "*", 
        
        RowBox[{"Exp", "[", 
         RowBox[{"rate", "*", "\[ScriptCapitalT]"}], "]"}]}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"\[ScriptCapitalK]", "=", 
      RowBox[{"Max", "[", 
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{"tmp1", "\[LeftDoubleBracket]", 
          RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
         RowBox[{
          RowBox[{"#", "<", "\[ScriptCapitalF]"}], "&"}]}], "]"}], "]"}]}], 
     ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"puts", "=", 
      RowBox[{
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{"data", "\[LeftDoubleBracket]", 
          RowBox[{"All", ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "4", ",", "5"}], "}"}]}], 
          "\[RightDoubleBracket]"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{
           "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "<", 
           "\[ScriptCapitalK]"}], "&"}]}], "]"}], "//.", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"___", ",", 
          RowBox[{"{", 
           RowBox[{"_", ",", "0.", ",", "_"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"_", ",", "0.", ",", "_"}], "}"}], ",", "x___"}], "}"}], 
        "\[RuleDelayed]", 
        RowBox[{"{", "x", "}"}]}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"calls", "=", 
      RowBox[{
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{"data", "\[LeftDoubleBracket]", 
          RowBox[{"All", ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "2", ",", "3"}], "}"}]}], 
          "\[RightDoubleBracket]"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{
           "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ">", 
           "\[ScriptCapitalK]"}], "&"}]}], "]"}], "//.", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"x___", ",", 
          RowBox[{"{", 
           RowBox[{"_", ",", "0.", ",", "_"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"_", ",", "0.", ",", "_"}], "}"}], ",", "___"}], "}"}], 
        "\[RuleDelayed]", 
        RowBox[{"{", "x", "}"}]}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"K0", "=", 
      RowBox[{
       RowBox[{"Select", "[", 
        RowBox[{"data", ",", 
         RowBox[{
          RowBox[{
           RowBox[{
           "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
           "\[Equal]", "\[ScriptCapitalK]"}], "&"}]}], "]"}], "/.", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "x5_"}], 
         "}"}], "\[RuleDelayed]", 
        RowBox[{"{", 
         RowBox[{"x1", ",", 
          RowBox[{"Mean", "@", 
           RowBox[{"{", 
            RowBox[{"x2", ",", "x3"}], "}"}]}], ",", 
          RowBox[{"Mean", "@", 
           RowBox[{"{", 
            RowBox[{"x4", ",", "x5"}], "}"}]}]}], "}"}]}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"#1", ",", 
         RowBox[{"0.5", "*", 
          RowBox[{"(", 
           RowBox[{"#2", "+", "#3"}], ")"}]}]}], "}"}], "&"}], "@@@", 
      RowBox[{"DeleteCases", "[", 
       RowBox[{
        RowBox[{"Join", "[", 
         RowBox[{"puts", ",", "K0", ",", "calls"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"_", ",", "0.", ",", "_"}], "}"}]}], "]"}]}]}]}], 
   "\[IndentingNewLine]", "]"}]}]}], "Input",
 CellChangeTimes->{{3.469363364532826*^9, 3.469363483263266*^9}, {
   3.469364295809856*^9, 3.469364487080785*^9}, {3.469364684772934*^9, 
   3.469364713098575*^9}, {3.469364982304281*^9, 3.4693650855764637`*^9}, {
   3.469365126603579*^9, 3.469365127538681*^9}, {3.469367768310955*^9, 
   3.469367786317272*^9}, 3.4693679998129263`*^9, 3.470139480514659*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"nearMidQuotePrice", "=", 
  RowBox[{"processOptionData1", "[", 
   RowBox[{"near", ",", "0.0038", ",", "9"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.469364497044786*^9, 3.469364520676497*^9}, 
   3.4693647385550337`*^9, 3.4693651048442507`*^9, {3.469365138705859*^9, 
   3.4693651407138033`*^9}, {3.469368153920043*^9, 3.4693681642291393`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"400", ",", "0.125`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"425", ",", "0.125`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"450", ",", "0.125`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"470", ",", "0.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"475", ",", "0.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"480", ",", "0.175`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"490", ",", "0.42500000000000004`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"500", ",", "0.175`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"510", ",", "0.225`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"520", ",", "0.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"525", ",", "0.42500000000000004`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"530", ",", "0.42500000000000004`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"540", ",", "0.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"550", ",", "0.15000000000000002`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"560", ",", "0.375`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"570", ",", "0.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"575", ",", "0.225`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"580", ",", "0.42500000000000004`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"585", ",", "0.425`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"590", ",", "0.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"595", ",", "0.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"600", ",", "0.375`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"605", ",", "0.45`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"610", ",", "0.45`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"615", ",", "0.475`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"620", ",", "0.475`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"625", ",", "0.65`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"630", ",", "0.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"635", ",", "0.525`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"640", ",", "0.675`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"645", ",", "0.6000000000000001`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"650", ",", "0.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"655", ",", "0.725`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"660", ",", "0.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"665", ",", "0.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"670", ",", "0.925`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"675", ",", "1.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"680", ",", "1.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"690", ",", "1.275`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"700", ",", "1.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"710", ",", "1.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"720", ",", "2.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"725", ",", "2.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"730", ",", "2.45`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"740", ",", "2.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"750", ",", "3.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"760", ",", "3.925`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"770", ",", "4.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"775", ",", "4.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"780", ",", "5.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"790", ",", "6.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"800", ",", "6.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"805", ",", "7.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"810", ",", "8.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"815", ",", "8.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"820", ",", "9.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"825", ",", "10.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"830", ",", "11.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"835", ",", "11.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"840", ",", "12.45`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"845", ",", "13.35`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"850", ",", "14.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"855", ",", "15.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"860", ",", "16.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"865", ",", "17.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"870", ",", "19.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"875", ",", "20.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"880", ",", "21.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"885", ",", "22.85`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"890", ",", "24.450000000000003`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"895", ",", "26.45`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"900", ",", "27.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"905", ",", "29.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"910", ",", "31.700000000000003`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"915", ",", "33.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"920", ",", "36.900000000000006`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"925", ",", "33.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"930", ",", "32.45`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"935", ",", "28.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"940", ",", "27.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"945", ",", "24.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"950", ",", "23.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"955", ",", "19.85`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"960", ",", "17.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"965", ",", "15.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"970", ",", "14.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"975", ",", "13.65`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"980", ",", "11.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"985", ",", "9.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"990", ",", "8.65`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"995", ",", "7.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1000", ",", "7.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1005", ",", "5.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1010", ",", "4.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1015", ",", "4.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1020", ",", "4.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1025", ",", "3.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1030", ",", "2.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1035", ",", "2.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1040", ",", "1.875`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1045", ",", "1.475`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1050", ",", "1.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1055", ",", "1.025`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1060", ",", "1.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1065", ",", "0.725`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1070", ",", "0.6499999999999999`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1075", ",", "0.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1080", ",", "0.675`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1085", ",", "0.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1090", ",", "0.575`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1095", ",", "0.475`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1100", ",", "0.375`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1105", ",", "0.475`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1110", ",", "0.275`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1115", ",", "0.42500000000000004`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1120", ",", "0.275`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1125", ",", "0.325`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1130", ",", "0.47500000000000003`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1135", ",", "0.47500000000000003`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1140", ",", "0.375`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1145", ",", "0.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1150", ",", "0.19999999999999998`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1155", ",", "0.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1160", ",", "0.275`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1165", ",", "0.19999999999999998`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1170", ",", "0.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1175", ",", "0.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1180", ",", "0.42500000000000004`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1185", ",", "0.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1190", ",", "0.275`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1195", ",", "0.525`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1200", ",", "0.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1205", ",", "0.525`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1210", ",", "0.275`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1215", ",", "0.275`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1220", ",", "0.525`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.469455097749215*^9, 3.469536498866495*^9, 
  3.469536549339348*^9, 3.470139174278408*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"nextMidQuotePrice", "=", 
  RowBox[{"processOptionData1", "[", 
   RowBox[{"next", ",", "0.0038", ",", "37"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.469365191644637*^9, 3.469365194971203*^9}, {
  3.469368170167458*^9, 3.469368176085541*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"200", ",", "0.325`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"300", ",", "0.30000000000000004`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"350", ",", "0.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"375", ",", "0.35`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"400", ",", "0.525`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"450", ",", "0.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"475", ",", "1.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"500", ",", "1.675`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"525", ",", "1.875`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"550", ",", "2.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"575", ",", "3.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"600", ",", "4.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"610", ",", "4.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"615", ",", "5.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"620", ",", "5.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"625", ",", "5.550000000000001`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"630", ",", "5.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"635", ",", "6.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"640", ",", "6.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"650", ",", "6.949999999999999`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"660", ",", "7.65`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"670", ",", "8.45`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"675", ",", "8.65`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"680", ",", "9.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"690", ",", "10.100000000000001`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"700", ",", "10.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"710", ",", "11.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"720", ",", "12.85`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"725", ",", "13.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"730", ",", "14.149999999999999`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"740", ",", "15.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"750", ",", "16.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"760", ",", "18.049999999999997`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"770", ",", "19.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"775", ",", "20.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"780", ",", "21.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"790", ",", "23.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"800", ",", "25.35`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"805", ",", "26.299999999999997`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"810", ",", "27.35`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"815", ",", "28.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"820", ",", "29.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"825", ",", "30.549999999999997`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"830", ",", "31.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"835", ",", "32.85`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"840", ",", "34.35`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"845", ",", "35.45`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"850", ",", "36.85`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"855", ",", "37.45`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"860", ",", "39.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"865", ",", "41.150000000000006`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"870", ",", "42.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"875", ",", "44.400000000000006`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"880", ",", "46.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"885", ",", "47.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"890", ",", "49.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"895", ",", "51.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"900", ",", "52.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"905", ",", "54.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"910", ",", "56.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"915", ",", "58.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"920", ",", "61.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"925", ",", "58.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"930", ",", "55.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"935", ",", "53.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"940", ",", "50.150000000000006`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"945", ",", "48.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"950", ",", "46.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"955", ",", "42.849999999999994`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"960", ",", "40.650000000000006`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"965", ",", "38.150000000000006`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"970", ",", "36.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"975", ",", "34.25`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"980", ",", "31.45`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"985", ",", "29.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"990", ",", "27.85`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"995", ",", "25.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1000", ",", "24.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1005", ",", "22.35`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1010", ",", "20.85`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1015", ",", "19.15`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1020", ",", "18.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1025", ",", "16.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1030", ",", "15.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1035", ",", "13.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1040", ",", "12.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1045", ",", "11.45`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1050", ",", "11.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1055", ",", "9.35`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1060", ",", "9.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1065", ",", "7.75`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1070", ",", "6.85`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1075", ",", "6.35`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1080", ",", "5.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1085", ",", "5.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1090", ",", "4.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1095", ",", "3.9000000000000004`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1100", ",", "3.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1105", ",", "3.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1110", ",", "2.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1115", ",", "2.4749999999999996`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1120", ",", "2.225`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1125", ",", "2.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1130", ",", "1.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1135", ",", "1.2999999999999998`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1140", ",", "1.375`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1145", ",", "1.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1150", ",", "0.825`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1155", ",", "0.725`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1160", ",", "0.6000000000000001`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.469455097783177*^9, 3.469536499347756*^9, 
  3.4695365493938103`*^9, 3.470139174349369*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Step 2. Calculate volatility for both near-term and next-term options\
\>", "Section",
 CellChangeTimes->{{3.469454232076521*^9, 3.4694542447444363`*^9}, 
   3.470139894394536*^9}],

Cell[TextData[{
 "\[OpenCurlyDoubleQuote]",
 StyleBox["Generally, ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   RowBox[{"\:2206", "\[VeryThinSpace]", 
    SubscriptBox["K", "i"]}], TraditionalForm]],
  FontSlant->"Italic"],
 StyleBox[" is half the difference between the strike prices on either side \
of ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["K", "i"], TraditionalForm]],
  FontSlant->"Italic"],
 StyleBox[". \[Ellipsis]At the upper and lower edges of any given strip of \
options, ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   RowBox[{"\:2206", "\[VeryThinSpace]", 
    SubscriptBox["K", "i"]}], TraditionalForm]],
  FontSlant->"Italic"],
 StyleBox[" is simply the difference between ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["K", "i"], TraditionalForm]],
  FontSlant->"Italic"],
 StyleBox[" and the adjacent strike price.",
  FontSlant->"Italic"],
 "\[CloseCurlyDoubleQuote]"
}], "Text",
 CellChangeTimes->{{3.4693680661459*^9, 3.469368112351377*^9}, {
  3.469368366029046*^9, 3.4693683710276413`*^9}, {3.469369227587483*^9, 
  3.469369227977152*^9}}],

Cell[TextData[{
 "The function ",
 StyleBox["ListCorrelate", "MB"],
 " can be used to create the the list of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\:2206", "\[VeryThinSpace]", 
    SubscriptBox["K", "i"]}], TraditionalForm]]],
 " values. For example:"
}], "Text",
 CellChangeTimes->{{3.46936830241603*^9, 3.469368316110774*^9}, {
  3.469368358362095*^9, 3.469368410296906*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListCorrelate", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], ",", "0", ",", 
     FractionBox["1", "2"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["x", "1"], ",", 
     SubscriptBox["x", "2"], ",", 
     SubscriptBox["x", "3"], ",", 
     SubscriptBox["x", "4"], ",", 
     SubscriptBox["x", "5"], ",", 
     SubscriptBox["x", "6"], ",", 
     SubscriptBox["x", "7"], ",", 
     SubscriptBox["x", "8"], ",", 
     SubscriptBox["x", "9"]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.469368391195005*^9, 3.469368400363473*^9}, {
  3.469368641339374*^9, 3.469368688027255*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      SubscriptBox["x", "1"], "2"]}], "+", 
    FractionBox[
     SubscriptBox["x", "3"], "2"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      SubscriptBox["x", "2"], "2"]}], "+", 
    FractionBox[
     SubscriptBox["x", "4"], "2"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      SubscriptBox["x", "3"], "2"]}], "+", 
    FractionBox[
     SubscriptBox["x", "5"], "2"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      SubscriptBox["x", "4"], "2"]}], "+", 
    FractionBox[
     SubscriptBox["x", "6"], "2"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      SubscriptBox["x", "5"], "2"]}], "+", 
    FractionBox[
     SubscriptBox["x", "7"], "2"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      SubscriptBox["x", "6"], "2"]}], "+", 
    FractionBox[
     SubscriptBox["x", "8"], "2"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      SubscriptBox["x", "7"], "2"]}], "+", 
    FractionBox[
     SubscriptBox["x", "9"], "2"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.469455097815095*^9, 3.469536499478648*^9, 
  3.469536549441266*^9, 3.47013917441117*^9}]
}, Open  ]],

Cell[TextData[{
 "Only the elements in position #1 in the list of mid quote prices, i.e. the \
strike prices, are used for this calculation. These elements can be selected \
by using the syntax ",
 StyleBox["\[LeftDoubleBracket]All,1\[RightDoubleBracket]", "MB"],
 "."
}], "Text",
 CellChangeTimes->{{3.469368532005165*^9, 3.4693685587723923`*^9}, {
  3.469368812732999*^9, 3.469368899075881*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"nearMidQuotePrice", "\[LeftDoubleBracket]", 
  RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}]], "Input",
 CellChangeTimes->{{3.469368460092906*^9, 3.4693684741955547`*^9}, 
   3.469368626601388*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "400", ",", "425", ",", "450", ",", "470", ",", "475", ",", "480", ",", 
   "490", ",", "500", ",", "510", ",", "520", ",", "525", ",", "530", ",", 
   "540", ",", "550", ",", "560", ",", "570", ",", "575", ",", "580", ",", 
   "585", ",", "590", ",", "595", ",", "600", ",", "605", ",", "610", ",", 
   "615", ",", "620", ",", "625", ",", "630", ",", "635", ",", "640", ",", 
   "645", ",", "650", ",", "655", ",", "660", ",", "665", ",", "670", ",", 
   "675", ",", "680", ",", "690", ",", "700", ",", "710", ",", "720", ",", 
   "725", ",", "730", ",", "740", ",", "750", ",", "760", ",", "770", ",", 
   "775", ",", "780", ",", "790", ",", "800", ",", "805", ",", "810", ",", 
   "815", ",", "820", ",", "825", ",", "830", ",", "835", ",", "840", ",", 
   "845", ",", "850", ",", "855", ",", "860", ",", "865", ",", "870", ",", 
   "875", ",", "880", ",", "885", ",", "890", ",", "895", ",", "900", ",", 
   "905", ",", "910", ",", "915", ",", "920", ",", "925", ",", "930", ",", 
   "935", ",", "940", ",", "945", ",", "950", ",", "955", ",", "960", ",", 
   "965", ",", "970", ",", "975", ",", "980", ",", "985", ",", "990", ",", 
   "995", ",", "1000", ",", "1005", ",", "1010", ",", "1015", ",", "1020", 
   ",", "1025", ",", "1030", ",", "1035", ",", "1040", ",", "1045", ",", 
   "1050", ",", "1055", ",", "1060", ",", "1065", ",", "1070", ",", "1075", 
   ",", "1080", ",", "1085", ",", "1090", ",", "1095", ",", "1100", ",", 
   "1105", ",", "1110", ",", "1115", ",", "1120", ",", "1125", ",", "1130", 
   ",", "1135", ",", "1140", ",", "1145", ",", "1150", ",", "1155", ",", 
   "1160", ",", "1165", ",", "1170", ",", "1175", ",", "1180", ",", "1185", 
   ",", "1190", ",", "1195", ",", "1200", ",", "1205", ",", "1210", ",", 
   "1215", ",", "1220"}], "}"}]], "Output",
 CellChangeTimes->{3.46945509784799*^9, 3.469536499549505*^9, 
  3.469536549492594*^9, 3.470139174460575*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListCorrelate", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.5"}], ",", "0", ",", "0.5"}], "}"}], ",", 
   RowBox[{"nearMidQuotePrice", "\[LeftDoubleBracket]", 
    RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}]}], "]"}]], "Input",
 CellChangeTimes->{3.469368748604301*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "25.`", ",", "22.5`", ",", "12.5`", ",", "5.`", ",", "7.5`", ",", "10.`", 
   ",", "10.`", ",", "10.`", ",", "7.5`", ",", "5.`", ",", "7.5`", ",", 
   "10.`", ",", "10.`", ",", "10.`", ",", "7.5`", ",", "5.`", ",", "5.`", ",",
    "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", 
   "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", 
   "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", 
   "5.`", ",", "7.5`", ",", "10.`", ",", "10.`", ",", "10.`", ",", "7.5`", 
   ",", "5.`", ",", "7.5`", ",", "10.`", ",", "10.`", ",", "10.`", ",", 
   "7.5`", ",", "5.`", ",", "7.5`", ",", "10.`", ",", "7.5`", ",", "5.`", ",",
    "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", 
   "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", 
   "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", 
   "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", 
   "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", 
   "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", 
   "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", 
   "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", 
   "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", 
   "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", 
   "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", 
   "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", 
   "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", 
   "5.`", ",", "5.`", ",", "5.`", ",", "5.`"}], "}"}]], "Output",
 CellChangeTimes->{3.469455097881462*^9, 3.469536499644514*^9, 
  3.469536549537128*^9, 3.47013917451147*^9}]
}, Open  ]],

Cell[TextData[{
 "To complete the ouput, the bounday values need to be added. Subtract the \
first value from the second value, and the second last value from the last \
value. ",
 StyleBox["N", "MB"],
 " is used to convert from integer to real numbers."
}], "Text",
 CellChangeTimes->{{3.4693689240695887`*^9, 3.469369026182873*^9}, {
  3.4693694995934*^9, 3.4693695148013906`*^9}, {3.4694543426081038`*^9, 
  3.4694543650698643`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tmp1", "=", 
  RowBox[{"Flatten", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{
         RowBox[{"#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
         "-", 
         RowBox[{
         "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], "]"}],
        ",", 
       RowBox[{"ListCorrelate", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "0.5"}], ",", "0", ",", "0.5"}], "}"}], ",", "#"}], 
        "]"}], ",", 
       RowBox[{"N", "[", 
        RowBox[{
         RowBox[{"#", "\[LeftDoubleBracket]", 
          RowBox[{"-", "1"}], "\[RightDoubleBracket]"}], "-", 
         RowBox[{"#", "\[LeftDoubleBracket]", 
          RowBox[{"-", "2"}], "\[RightDoubleBracket]"}]}], "]"}]}], "}"}], 
     "&"}], "/@", 
    RowBox[{"{", 
     RowBox[{"nearMidQuotePrice", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], "}"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4692941270689573`*^9, 3.469294214022084*^9}, {
  3.469294245325224*^9, 3.4692943372489033`*^9}, {3.469294391277597*^9, 
  3.469294410931611*^9}, {3.469294742475885*^9, 3.469294746522317*^9}, {
  3.46936826429187*^9, 3.4693682755483093`*^9}, {3.4693685720270643`*^9, 
  3.4693685869525003`*^9}, {3.469369395023872*^9, 3.469369395924178*^9}, {
  3.469369488814557*^9, 3.469369496789164*^9}, {3.469369529455598*^9, 
  3.46936956696071*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "25.`", ",", "25.`", ",", "22.5`", ",", "12.5`", ",", "5.`", ",", "7.5`", 
   ",", "10.`", ",", "10.`", ",", "10.`", ",", "7.5`", ",", "5.`", ",", 
   "7.5`", ",", "10.`", ",", "10.`", ",", "10.`", ",", "7.5`", ",", "5.`", 
   ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", 
   ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", 
   ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", 
   ",", "5.`", ",", "5.`", ",", "7.5`", ",", "10.`", ",", "10.`", ",", "10.`",
    ",", "7.5`", ",", "5.`", ",", "7.5`", ",", "10.`", ",", "10.`", ",", 
   "10.`", ",", "7.5`", ",", "5.`", ",", "7.5`", ",", "10.`", ",", "7.5`", 
   ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", 
   ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", 
   ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", 
   ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", 
   ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", 
   ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", 
   ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", 
   ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", 
   ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", 
   ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", 
   ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", 
   ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", 
   ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", 
   ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`", ",", "5.`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.4694550979149*^9, 3.469536499744648*^9, 
  3.469536549636878*^9, 3.470139174578373*^9}]
}, Open  ]],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{"\:2206", "\[VeryThinSpace]", 
     SubscriptBox["K", "i"]}], 
    RowBox[{"\[VeryThinSpace]", 
     SuperscriptBox[
      SubscriptBox["K", "i"], "2"]}]], TraditionalForm]]],
 "is obtained by dividing this list by the squared list of the strike \
prices:"
}], "Text",
 CellChangeTimes->{{3.4693692410877237`*^9, 3.469369366646908*^9}, {
  3.469454394112661*^9, 3.469454398854437*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tmp1", "/", 
  SuperscriptBox[
   RowBox[{"nearMidQuotePrice", "\[LeftDoubleBracket]", 
    RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], "2"]}]], "Input",
 CellChangeTimes->{{3.469294413688383*^9, 3.469294447530778*^9}, 
   3.4693693764017572`*^9, {3.4693694464046803`*^9, 3.469369447731244*^9}, {
   3.469369550357986*^9, 3.4693695725418997`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.00015625`", ",", "0.0001384083044982699`", ",", 
   "0.00011111111111111112`", ",", "0.00005658669081032141`", ",", 
   "0.0000221606648199446`", ",", "0.00003255208333333333`", ",", 
   "0.000041649312786339026`", ",", "0.000039999999999999996`", ",", 
   "0.00003844675124951942`", ",", "0.000027736686390532543`", ",", 
   "0.000018140589569160997`", ",", "0.0000266998932004272`", ",", 
   "0.00003429355281207133`", ",", "0.00003305785123966942`", ",", 
   "0.00003188775510204082`", ",", "0.00002308402585410896`", ",", 
   "0.000015122873345935728`", ",", "0.000014863258026159334`", ",", 
   "0.000014610271020527432`", ",", "0.000014363688595231255`", ",", 
   "0.000014123296377374479`", ",", "0.00001388888888888889`", ",", 
   "0.000013660269107301414`", ",", "0.000013437248051599033`", ",", 
   "0.000013219644391565866`", ",", "0.000013007284079084288`", ",", 
   "0.0000128`", ",", "0.000012597631645250693`", ",", 
   "0.0000124000248000496`", ",", "0.00001220703125`", ",", 
   "0.000012018508503094765`", ",", "0.000011834319526627219`", ",", 
   "0.00001165433249810617`", ",", "0.000011478420569329661`", ",", 
   "0.000011306461642828876`", ",", "0.000011138338159946536`", ",", 
   "0.000010973936899862826`", ",", "0.000016219723183391005`", ",", 
   "0.000021003990758244064`", ",", "0.00002040816326530612`", ",", 
   "0.000019837333862328903`", ",", "0.000014467592592592593`", ",", 
   "9.512485136741973`*^-6", ",", "0.0000140739350722462`", ",", 
   "0.000018261504747991233`", ",", "0.000017777777777777777`", ",", 
   "0.000017313019390581715`", ",", "0.0000126496879743633`", ",", 
   "8.324661810613944`*^-6", ",", "0.00001232741617357002`", ",", 
   "0.00001602307322544464`", ",", "0.00001171875`", ",", 
   "7.715751707110064`*^-6", ",", "7.6207895137936296`*^-6", ",", 
   "7.527569724114569`*^-6", ",", "7.436049970255801`*^-6", ",", 
   "7.346189164370983`*^-6", ",", "7.257947452460444`*^-6", ",", 
   "7.17128617017462`*^-6", ",", "7.086167800453515`*^-6", ",", 
   "7.002555932915514`*^-6", ",", "6.9204152249134946`*^-6", ",", 
   "6.839711364180432`*^-6", ",", "6.760411032990806`*^-6", ",", 
   "6.682481873767917`*^-6", ",", "6.605892456070816`*^-6", ",", 
   "6.53061224489796`*^-6", ",", "6.4566115702479346`*^-6", ",", 
   "6.383861597880558`*^-6", ",", "6.312334301224593`*^-6", ",", 
   "6.242002434380949`*^-6", ",", "6.17283950617284`*^-6", ",", 
   "6.104819755196728`*^-6", ",", "6.037918125830213`*^-6", ",", 
   "5.972110245155125`*^-6", ",", "5.907372400756143`*^-6", ",", 
   "5.843681519357195`*^-6", ",", "5.781015146259683`*^-6", ",", 
   "5.719351425548343`*^-6", ",", "5.658669081032141`*^-6", ",", 
   "5.598947397889197`*^-6", ",", "5.54016620498615`*^-6", ",", 
   "5.482305857843809`*^-6", ",", "5.4253472222222224`*^-6", ",", 
   "5.369271658299551`*^-6", ",", "5.314061005420342`*^-6", ",", 
   "5.259697567389876`*^-6", ",", "5.206164098292378`*^-6", ",", 
   "5.153443788811873`*^-6", ",", "5.101520253035404`*^-6", ",", 
   "5.050377515719299`*^-6", ",", "4.9999999999999996`*^-6", ",", 
   "4.950372515531794`*^-6", ",", "4.901480247034604`*^-6", ",", 
   "4.853308743235701`*^-6", ",", "4.805843906189927`*^-6", ",", 
   "4.759071980963712`*^-6", ",", "4.712979545668772`*^-6", ",", 
   "4.667553501832015`*^-6", ",", "4.6227810650887575`*^-6", ",", 
   "4.5786497561869005`*^-6", ",", "4.535147392290249`*^-6", ",", 
   "4.492262078569664`*^-6", ",", "4.4499822000711994`*^-6", ",", 
   "4.408296413850868`*^-6", ",", "4.367193641366058`*^-6", ",", 
   "4.326663061114116`*^-6", ",", "4.2866941015089165`*^-6", ",", 
   "4.247276433986706`*^-6", ",", "4.2083999663328`*^-6", ",", 
   "4.170054836221096`*^-6", ",", "4.132231404958678`*^-6", ",", 
   "4.094920251428103`*^-6", ",", "4.058112166220275`*^-6", ",", 
   "4.021798145951055`*^-6", ",", "3.985969387755102`*^-6", ",", 
   "3.9506172839506175`*^-6", ",", "3.91573341686898`*^-6", ",", 
   "3.881309553843467`*^-6", ",", "3.847337642351493`*^-6", ",", 
   "3.8138098053050095`*^-6", ",", "3.780718336483932`*^-6", ",", 
   "3.7480556961076443`*^-6", ",", "3.7158145065398335`*^-6", ",", 
   "3.6839875481220875`*^-6", ",", "3.652567755131858`*^-6", ",", 
   "3.6215482118605707`*^-6", ",", "3.5909221488078137`*^-6", ",", 
   "3.5606829389876974`*^-6", ",", "3.5308240943436198`*^-6", ",", 
   "3.5013392622678176`*^-6", ",", "3.4722222222222224`*^-6", ",", 
   "3.4434668824572577`*^-6", ",", "3.4150672768253536`*^-6", ",", 
   "3.3870175616860573`*^-6", ",", "3.3593120128997583`*^-6"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.469455097948543*^9, 3.469536499829934*^9, 
  3.469536549693472*^9, 3.4701391746455927`*^9}]
}, Open  ]],

Cell[TextData[{
 "Remembering that ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Q", "(", 
    SubscriptBox["K", "i"], ")"}], TraditionalForm]]],
 " is the second term in the list of mid price quotes, i.e. ",
 StyleBox["nearMidQuotePrice\[LeftDoubleBracket]All, 2\[RightDoubleBracket]", 
  "MB"],
 ", it follows that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox[
     RowBox[{"\:2206", "\[VeryThinSpace]", 
      SubscriptBox["K", "i"]}], 
     RowBox[{"\[VeryThinSpace]", 
      SuperscriptBox[
       SubscriptBox["K", "i"], "2"]}]], 
    RowBox[{"Q", "(", 
     SubscriptBox["K", "i"], ")"}]}], TraditionalForm]]],
 " is the list immediately above multiplied by ",
 StyleBox["nearMidQuotePrice\[LeftDoubleBracket]All, 2\[RightDoubleBracket]", 
  "MB"],
 "."
}], "Text",
 CellChangeTimes->{{3.4693692410877237`*^9, 3.469369366646908*^9}, {
  3.469369799058138*^9, 3.469369905379394*^9}, {3.469454415138226*^9, 
  3.469454428595336*^9}, {3.470139574285665*^9, 3.4701395760757732`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tmp", "=", 
  RowBox[{"Flatten", "[", 
   RowBox[{"tmp1", "*", 
    RowBox[{
     RowBox[{"nearMidQuotePrice", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], "/", 
     SuperscriptBox[
      RowBox[{"nearMidQuotePrice", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], "2"]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.469294430018715*^9, 3.469294436800992*^9}, {
   3.469294523181485*^9, 3.469294534067295*^9}, 3.469294616591898*^9, {
   3.4692946915931463`*^9, 3.469294695423818*^9}, 3.469294839790205*^9, {
   3.469294899534041*^9, 3.469294925365081*^9}, {3.4693695995847387`*^9, 
   3.469369612974059*^9}, 3.469369764402874*^9, {3.469454475284009*^9, 
   3.469454476189788*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.00001953125`", ",", "0.00001730103806228374`", ",", 
   "0.00001388888888888889`", ",", "8.488003621548212`*^-6", ",", 
   "3.3240997229916898`*^-6", ",", "5.696614583333333`*^-6", ",", 
   "0.000017700957934194085`", ",", "7.`*^-6", ",", "8.65051903114187`*^-6", 
   ",", "0.000011094674556213017`", ",", "7.709750566893424`*^-6", ",", 
   "0.00001134745461018156`", ",", "0.000013717421124828532`", ",", 
   "4.958677685950413`*^-6", ",", "0.000011957908163265306`", ",", 
   "9.233610341643583`*^-6", ",", "3.402646502835539`*^-6", ",", 
   "6.316884661117717`*^-6", ",", "6.209365183724158`*^-6", ",", 
   "5.745475438092502`*^-6", ",", "3.5308240943436198`*^-6", ",", 
   "5.208333333333334`*^-6", ",", "6.147121098285637`*^-6", ",", 
   "6.046761623219565`*^-6", ",", "6.279331085993786`*^-6", ",", 
   "6.178459937565036`*^-6", ",", "8.32`*^-6", ",", "6.298815822625346`*^-6", 
   ",", "6.51001302002604`*^-6", ",", "8.23974609375`*^-6", ",", 
   "7.21110510185686`*^-6", ",", "9.467455621301774`*^-6", ",", 
   "8.449391061126974`*^-6", ",", "9.182736455463728`*^-6", ",", 
   "8.479846232121656`*^-6", ",", "0.000010302962797950546`", ",", 
   "0.000010973936899862826`", ",", "0.000017030709342560555`", ",", 
   "0.000026780088216761185`", ",", "0.00003061224489795918`", ",", 
   "0.00003471533425907558`", ",", "0.000029658564814814815`", ",", 
   "0.000023781212841854935`", ",", "0.00003448114092700319`", ",", 
   "0.000052958363769174576`", ",", "0.00006311111111111112`", ",", 
   "0.00006795360110803323`", ",", "0.000060718502276943836`", ",", 
   "0.00004079084287200832`", ",", "0.0000665680473372781`", ",", 
   "0.00009934305399775677`", ",", "0.0000796875`", ",", 
   "0.000059797075730103005`", ",", "0.00006325255296448713`", ",", 
   "0.00006699537054461968`", ",", "0.0000706424747174301`", ",", 
   "0.00007493112947658403`", ",", "0.00007983742197706488`", ",", 
   "0.00008426261249955178`", ",", "0.00008822278911564625`", ",", 
   "0.00009348412170442212`", ",", "0.00010207612456747406`", ",", 
   "0.0001060155261447967`", ",", "0.00011222282314764739`", ",", 
   "0.00011827992916569214`", ",", "0.0001255119566653455`", ",", 
   "0.00013191836734693878`", ",", "0.00013946280991735538`", ",", 
   "0.00014587123751157077`", ",", "0.00015433657366494132`", ",", 
   "0.00016510096438937608`", ",", "0.00016820987654320987`", ",", 
   "0.00018161838771710265`", ",", "0.0001914020045888178`", ",", 
   "0.00020036429872495446`", ",", "0.00021798204158790172`", ",", 
   "0.00019459459459459456`", ",", "0.00018759394149612675`", ",", 
   "0.00016443135348451486`", ",", "0.00015561339972838389`", ",", 
   "0.00013437473754934073`", ",", "0.00012742382271468145`", ",", 
   "0.00010882377127819962`", ",", "0.00009521484375`", ",", 
   "0.00008563988294987784`", ",", "0.00007545966627696884`", ",", 
   "0.0000717948717948718`", ",", "0.00005830903790087463`", ",", 
   "0.00005127676569867813`", ",", "0.00004412815018875625`", ",", 
   "0.00003813035024368071`", ",", "0.000035`", ",", 
   "0.00002772208608697804`", ",", "0.000023527105185766103`", ",", 
   "0.000019898565847266373`", ",", "0.000019463667820069203`", ",", 
   "0.000014515169541939321`", ",", "0.000012018097841455369`", ",", 
   "0.000010035240028938833`", ",", "8.66771449704142`*^-6", ",", 
   "6.753508390375679`*^-6", ",", "7.029478458049887`*^-6", ",", 
   "4.604568630533905`*^-6", ",", "5.117479530081879`*^-6", ",", 
   "3.196014900041879`*^-6", ",", "2.8386758668879374`*^-6", ",", 
   "3.244997295835587`*^-6", ",", "2.8935185185185184`*^-6", ",", 
   "2.3360020386926884`*^-6", ",", "2.41982998064136`*^-6", ",", 
   "1.9807760472050207`*^-6", ",", "1.549586776859504`*^-6", ",", 
   "1.945087119428349`*^-6", ",", "1.1159808457105756`*^-6", ",", 
   "1.7092642120291984`*^-6", ",", "1.096141581632653`*^-6", ",", 
   "1.2839506172839507`*^-6", ",", "1.8599733730127655`*^-6", ",", 
   "1.843622038075647`*^-6", ",", "1.44275161588181`*^-6", ",", 
   "1.9069049026525047`*^-6", ",", "7.561436672967863`*^-7", ",", 
   "1.8740278480538221`*^-6", ",", "1.0218489892984542`*^-6", ",", 
   "7.367975096244175`*^-7", ",", "9.131419387829645`*^-7", ",", 
   "3.6215482118605705`*^-7", ",", "1.5261419132433212`*^-6", ",", 
   "5.341024408481547`*^-7", ",", "9.709766259444954`*^-7", ",", 
   "1.8382031126906045`*^-6", ",", "3.4722222222222224`*^-7", ",", 
   "1.8078201132900604`*^-6", ",", "9.391435011269723`*^-7", ",", 
   "9.314298294636658`*^-7", ",", "1.7636388067723732`*^-6"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.4694550979816504`*^9, 3.469536499947525*^9, 
  3.469536549759698*^9, 3.470139174712255*^9}]
}, Open  ]],

Cell[TextData[{
 "Multiplying this list by ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"2", "/", "T"}], ")"}], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"R", "\[VeryThinSpace]", "T"}]]}], TraditionalForm]],
  CellChangeTimes->{{3.469369943748357*^9, 3.469370096762732*^9}}],
 " and summing the terms gives the expression for:"
}], "Text",
 CellChangeTimes->{{3.4693701045600243`*^9, 3.46937017971208*^9}, {
  3.4701395892628927`*^9, 3.470139589411874*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    UnderscriptBox[
     RowBox[{
      FractionBox["2", "T"], "\[Sum]"}], "i"], 
    FractionBox[
     RowBox[{"\:2206", "\[VeryThinSpace]", 
      SubscriptBox["K", "i"]}], 
     RowBox[{"\[VeryThinSpace]", 
      SuperscriptBox[
       SubscriptBox["K", "i"], "2"]}]], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"R", "\[VeryThinSpace]", "T"}]], 
    RowBox[{"Q", "(", 
     SubscriptBox["K", "i"], ")"}]}], "=", 
   RowBox[{
    UnderscriptBox[
     RowBox[{
      FractionBox["2", "T"], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"R", "\[VeryThinSpace]", "T"}]], "\[Sum]"}], "i"], 
    FractionBox[
     RowBox[{"\:2206", "\[VeryThinSpace]", 
      SubscriptBox["K", "i"]}], 
     RowBox[{"\[VeryThinSpace]", 
      SuperscriptBox[
       SubscriptBox["K", "i"], "2"]}]], 
    RowBox[{"Q", "(", 
     SubscriptBox["K", "i"], ")"}]}]}], TraditionalForm]], "Text",
 CellChangeTimes->{{3.469369943748357*^9, 3.469370096762732*^9}},
 TextAlignment->Center,
 TextJustification->0.],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  FractionBox["2", 
   SubscriptBox["\[ScriptCapitalT]", "1"]], "*", 
  RowBox[{"Exp", "[", 
   RowBox[{
    SubscriptBox["r", "\[ScriptF]"], "*", 
    SubscriptBox["\[ScriptCapitalT]", "1"]}], "]"}], "*", 
  RowBox[{"Total", "[", "tmp", "]"}]}]], "Input",
 CellChangeTimes->{{3.469370215692626*^9, 3.4693702313557262`*^9}, 
   3.469370520572898*^9, {3.4694544961028357`*^9, 3.469454528284987*^9}}],

Cell[BoxData["0.4727792063061052`"], "Output",
 CellChangeTimes->{3.469455098014081*^9, 3.469536500020637*^9, 
  3.469536549826098*^9, 3.4701391747767963`*^9}]
}, Open  ]],

Cell[TextData[{
 "Note here that ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " works on entire lists, there is no need to loop through the list to sum \
the terms. The next step is to subtract the term"
}], "Text",
 CellChangeTimes->{{3.4693702413390427`*^9, 3.469370277066265*^9}, {
  3.469370321797532*^9, 3.469370334539535*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "T"], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      FractionBox["F", 
       SubscriptBox["K", "0"]], "-", "1"}], ")"}], "2"]}], 
  TraditionalForm]], "DisplayFormula",
 CellChangeTimes->{{3.469370347810141*^9, 3.469370371081592*^9}},
 TextAlignment->Center,
 TextJustification->0.],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"2", "*", 
   FractionBox[
    RowBox[{"Exp", "[", 
     RowBox[{
      SubscriptBox["r", "\[ScriptF]"], "*", 
      SubscriptBox["\[ScriptCapitalT]", "1"]}], "]"}], 
    SubscriptBox["\[ScriptCapitalT]", "1"]], "*", 
   RowBox[{"Total", "[", "tmp", "]"}]}], "-", 
  RowBox[{
   FractionBox["1", 
    SubscriptBox["\[ScriptCapitalT]", "1"]], "*", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       SubscriptBox["\[ScriptCapitalF]", "1"], 
       SubscriptBox["\[ScriptCapitalK]", "0"]], "-", "1."}], ")"}], 
    "2"]}]}]], "Input",
 CellChangeTimes->{{3.469293267743105*^9, 3.4692932746744623`*^9}, 
   3.469293311146493*^9, {3.4692933464284067`*^9, 3.469293363353579*^9}, {
   3.469293435621624*^9, 3.4692934494118967`*^9}, {3.469294892125485*^9, 
   3.4692948933878403`*^9}, {3.469370392675939*^9, 3.469370393329108*^9}}],

Cell[BoxData["0.47276722522261405`"], "Output",
 CellChangeTimes->{3.4694550980477*^9, 3.4695365000812798`*^9, 
  3.4695365498760757`*^9, 3.470139174920493*^9}]
}, Open  ]],

Cell["These steps,", "Text",
 CellChangeTimes->{{3.4693704151267853`*^9, 3.469370429693548*^9}, {
  3.469370730679407*^9, 3.469370746989036*^9}, {3.469454569708268*^9, 
  3.4694545770345087`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"tmp1", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"N", "[", 
         RowBox[{
          RowBox[{"#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}],
           "-", 
          RowBox[{
          "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
         "]"}], ",", 
        RowBox[{"ListCorrelate", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.5"}], ",", "0", ",", "0.5"}], "}"}], ",", "#"}], 
         "]"}], ",", 
        RowBox[{"N", "[", 
         RowBox[{
          RowBox[{"#", "\[LeftDoubleBracket]", 
           RowBox[{"-", "1"}], "\[RightDoubleBracket]"}], "-", 
          RowBox[{"#", "\[LeftDoubleBracket]", 
           RowBox[{"-", "2"}], "\[RightDoubleBracket]"}]}], "]"}]}], "}"}], 
      "&"}], "/@", 
     RowBox[{"{", 
      RowBox[{"data", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], "}"}]}], "]"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tmp", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"tmp1", "*", 
     RowBox[{
      RowBox[{"data", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], "/", 
      SuperscriptBox[
       RowBox[{"data", "\[LeftDoubleBracket]", 
        RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], "2"]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"2", "*", 
   FractionBox[
    RowBox[{"Exp", "[", 
     RowBox[{
      SubscriptBox["r", "\[ScriptF]"], "*", 
      SubscriptBox["\[ScriptCapitalT]", "1"]}], "]"}], 
    SubscriptBox["\[ScriptCapitalT]", "1"]], "*", 
   RowBox[{"Total", "[", "tmp", "]"}]}], "-", 
  RowBox[{
   FractionBox["1", 
    SubscriptBox["\[ScriptCapitalT]", "1"]], "*", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       SubscriptBox["\[ScriptCapitalF]", "1"], 
       SubscriptBox["\[ScriptCapitalK]", "0"]], "-", "1."}], ")"}], 
    "2"]}]}]}], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.469370487940386*^9, 3.469370549834847*^9}, {
  3.469454551861631*^9, 3.469454556270293*^9}}],

Cell["can be added to the function defined above:", "Text",
 CellChangeTimes->{{3.4693704151267853`*^9, 3.469370429693548*^9}, {
   3.469370730679407*^9, 3.469370746989036*^9}, 3.469454573443716*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"processOptionData2", "[", 
   RowBox[{"data_", ",", "rate_", ",", "days_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "now", ",", "term", ",", "secondsPerYear", ",", "\[ScriptCapitalT]", ",",
       "tmp1", ",", "tmp", ",", "FData", ",", "\[ScriptCapitalF]", ",", 
      "\[ScriptCapitalK]", ",", "puts", ",", "calls", ",", "K0", ",", 
      "midQuotePrice"}], "}"}], ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{"calculate", " ", "expiration", " ", "time"}], " ", "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"now", "=", 
      RowBox[{"DateList", "[", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"term", "=", 
      RowBox[{"DatePlus", "[", 
       RowBox[{"now", ",", "days"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"secondsPerYear", "=", 
      RowBox[{"N", "[", 
       RowBox[{"365", "*", "24", "*", "60", "*", "60"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"\[ScriptCapitalT]", "=", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"AbsoluteTime", "[", "term", "]"}], "-", 
         RowBox[{"AbsoluteTime", "[", "now", "]"}]}], ")"}], "/", 
       "secondsPerYear"}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"process", " ", "data"}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"tmp1", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"#1", ",", 
          RowBox[{"Abs", "[", 
           RowBox[{
            RowBox[{"0.5", "*", 
             RowBox[{"(", 
              RowBox[{"#2", "+", "#3"}], ")"}]}], "-", 
            RowBox[{"0.5", "*", 
             RowBox[{"(", 
              RowBox[{"#4", "+", "#5"}], ")"}]}]}], "]"}]}], "}"}], "&"}], "@@@",
        "data"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"FData", "=", 
      RowBox[{"First", "@", 
       RowBox[{"Sort", "[", 
        RowBox[{"tmp1", ",", 
         RowBox[{
          RowBox[{
           RowBox[{
           "#1", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], "<", 
           
           RowBox[{
           "#2", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
          "&"}]}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"\[ScriptCapitalF]", "=", 
      RowBox[{
       RowBox[{
       "FData", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "+", 
       RowBox[{
        RowBox[{
        "FData", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], "*", 
        
        RowBox[{"Exp", "[", 
         RowBox[{"rate", "*", "\[ScriptCapitalT]"}], "]"}]}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"\[ScriptCapitalK]", "=", 
      RowBox[{"Max", "[", 
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{"tmp1", "\[LeftDoubleBracket]", 
          RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
         RowBox[{
          RowBox[{"#", "<", "\[ScriptCapitalF]"}], "&"}]}], "]"}], "]"}]}], 
     ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"puts", "=", 
      RowBox[{
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{"data", "\[LeftDoubleBracket]", 
          RowBox[{"All", ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "4", ",", "5"}], "}"}]}], 
          "\[RightDoubleBracket]"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{
           "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "<", 
           "\[ScriptCapitalK]"}], "&"}]}], "]"}], "//.", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"___", ",", 
          RowBox[{"{", 
           RowBox[{"_", ",", "0.", ",", "_"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"_", ",", "0.", ",", "_"}], "}"}], ",", "x___"}], "}"}], 
        "\[RuleDelayed]", 
        RowBox[{"{", "x", "}"}]}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"calls", "=", 
      RowBox[{
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{"data", "\[LeftDoubleBracket]", 
          RowBox[{"All", ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "2", ",", "3"}], "}"}]}], 
          "\[RightDoubleBracket]"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{
           "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ">", 
           "\[ScriptCapitalK]"}], "&"}]}], "]"}], "//.", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"x___", ",", 
          RowBox[{"{", 
           RowBox[{"_", ",", "0.", ",", "_"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"_", ",", "0.", ",", "_"}], "}"}], ",", "___"}], "}"}], 
        "\[RuleDelayed]", 
        RowBox[{"{", "x", "}"}]}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"K0", "=", 
      RowBox[{
       RowBox[{"Select", "[", 
        RowBox[{"data", ",", 
         RowBox[{
          RowBox[{
           RowBox[{
           "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
           "\[Equal]", "\[ScriptCapitalK]"}], "&"}]}], "]"}], "/.", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"x1_", ",", "x2_", ",", "x3_", ",", "x4_", ",", "x5_"}], 
         "}"}], "\[RuleDelayed]", 
        RowBox[{"{", 
         RowBox[{"x1", ",", 
          RowBox[{"Mean", "@", 
           RowBox[{"{", 
            RowBox[{"x2", ",", "x3"}], "}"}]}], ",", 
          RowBox[{"Mean", "@", 
           RowBox[{"{", 
            RowBox[{"x4", ",", "x5"}], "}"}]}]}], "}"}]}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"midQuotePrice", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"#1", ",", 
          RowBox[{"0.5", "*", 
           RowBox[{"(", 
            RowBox[{"#2", "+", "#3"}], ")"}]}]}], "}"}], "&"}], "@@@", 
       RowBox[{"DeleteCases", "[", 
        RowBox[{
         RowBox[{"Join", "[", 
          RowBox[{"puts", ",", "K0", ",", "calls"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"_", ",", "0.", ",", "_"}], "}"}]}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"calculation", " ", "of", " ", 
       SuperscriptBox["\[Sigma]", "2"]}], " ", "*)"}], "\[IndentingNewLine]", 
     
     RowBox[{"tmp1", "=", 
      RowBox[{"Flatten", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"N", "[", 
            RowBox[{
             RowBox[{
             "#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], "-", 
             RowBox[{
             "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
            "]"}], ",", 
           RowBox[{"ListCorrelate", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "0.5"}], ",", "0", ",", "0.5"}], "}"}], ",", 
             "#"}], "]"}], ",", 
           RowBox[{"N", "[", 
            RowBox[{
             RowBox[{"#", "\[LeftDoubleBracket]", 
              RowBox[{"-", "1"}], "\[RightDoubleBracket]"}], "-", 
             RowBox[{"#", "\[LeftDoubleBracket]", 
              RowBox[{"-", "2"}], "\[RightDoubleBracket]"}]}], "]"}]}], "}"}],
          "&"}], "/@", 
        RowBox[{"{", 
         RowBox[{"midQuotePrice", "\[LeftDoubleBracket]", 
          RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], "}"}]}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"tmp", "=", 
      RowBox[{"Flatten", "[", 
       RowBox[{"tmp1", "*", 
        RowBox[{
         RowBox[{"midQuotePrice", "\[LeftDoubleBracket]", 
          RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], "/", 
         SuperscriptBox[
          RowBox[{"midQuotePrice", "\[LeftDoubleBracket]", 
           RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], "2"]}]}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"2", "*", 
       FractionBox[
        RowBox[{"Exp", "[", 
         RowBox[{"rate", "*", "\[ScriptCapitalT]"}], "]"}], 
        "\[ScriptCapitalT]"], "*", 
       RowBox[{"Total", "[", "tmp", "]"}]}], "-", 
      RowBox[{
       FractionBox["1", "\[ScriptCapitalT]"], "*", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          FractionBox["\[ScriptCapitalF]", "\[ScriptCapitalK]"], "-", "1."}], 
         ")"}], "2"]}]}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.4693707068785477`*^9, 3.469370716582046*^9}, {
   3.469370758151621*^9, 3.4693708242566233`*^9}, {3.4693708845243263`*^9, 
   3.469370903166627*^9}, 3.470139627581607*^9}],

Cell[TextData[{
 "So given a list of options data of the form: ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     StyleBox[
      RowBox[{"strike", " ", "price"}],
      FontSlant->"Italic"], ",", 
     StyleBox[
      RowBox[{"call", " ", "bid"}],
      FontSlant->"Italic"], ",", 
     StyleBox[
      RowBox[{"call", " ", "ask"}],
      FontSlant->"Italic"], ",", 
     StyleBox[
      RowBox[{"put", " ", "bid"}],
      FontSlant->"Italic"], ",", 
     StyleBox[
      RowBox[{"put", " ", "ask"}],
      FontSlant->"Italic"]}], "}"}], TraditionalForm]]],
 ", a risk free rate, and the number of days to expiration, the ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Sigma]", "2"], TraditionalForm]]],
 ", i.e. eqn (",
 
 CounterBox["DisplayFormulaNumbered", "eqn1"],
 "), can be calculated. Note that the list of options data could be imported \
into ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " from e.g. an Excel spreadsheet. For example"
}], "Text",
 CellChangeTimes->{{3.469371330570825*^9, 3.469371416406434*^9}, {
   3.469454600869872*^9, 3.469454620595745*^9}, {3.47013963968111*^9, 
   3.470139644697238*^9}, {3.470139707472254*^9, 3.47013972211089*^9}, 
   3.470139766483584*^9, {3.470139800690652*^9, 3.4701398031442223`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"near", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"\"\<path/to/someOptionsData.xls\>\"", ",", "\"\<Data\>\""}], 
    "]"}]}], ";"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.470139806732832*^9, 3.470139831370809*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"processOptionData2", "[", 
  RowBox[{"near", ",", "0.0038", ",", "9"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"processOptionData2", "[", 
  RowBox[{"next", ",", "0.0038", ",", "37"}], "]"}]}], "Input",
 CellChangeTimes->{{3.4693708469537153`*^9, 3.469370851968279*^9}, {
  3.469370915434206*^9, 3.469370921274238*^9}}],

Cell[BoxData["0.47276722522261405`"], "Output",
 CellChangeTimes->{3.4694550981130457`*^9, 3.469536500695942*^9, 
  3.469536549941187*^9, 3.470139175020339*^9}],

Cell[BoxData["0.36681815471859974`"], "Output",
 CellChangeTimes->{3.4694550981130457`*^9, 3.469536500695942*^9, 
  3.469536549941187*^9, 3.470139175022646*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Step 3. Calculate the 30 day weighted average", "Section",
 CellChangeTimes->{{3.469296061462276*^9, 3.469296065179673*^9}, {
   3.469454640150383*^9, 3.469454647683968*^9}, 3.470139889421318*^9}],

Cell["The formula for the VIX\[RegisteredTrademark] is:", "Text",
 CellChangeTimes->{{3.4693774850033207`*^9, 3.469377491561761*^9}, {
  3.469454667630254*^9, 3.469454675068647*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"VIX", "=", 
   RowBox[{"100", "\[CenterDot]", 
    SqrtBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["\[ScriptCapitalT]", "1"], "\[CenterDot]", 
         SubsuperscriptBox["\[Sigma]", "1", "2"], "\[CenterDot]", 
         FractionBox[
          RowBox[{
           SubscriptBox["\[ScriptCapitalN]", "2"], "-", 
           SubscriptBox["\[ScriptCapitalN]", "30"]}], 
          RowBox[{
           SubscriptBox["\[ScriptCapitalN]", "2"], "-", 
           SubscriptBox["\[ScriptCapitalN]", "1"]}]]}], "+", 
        RowBox[{
         SubscriptBox["\[ScriptCapitalT]", "2"], "\[CenterDot]", 
         SubsuperscriptBox["\[Sigma]", "2", "2"], "\[CenterDot]", 
         FractionBox[
          RowBox[{
           SubscriptBox["\[ScriptCapitalN]", "30"], "-", 
           SubscriptBox["\[ScriptCapitalN]", "1"]}], 
          RowBox[{
           SubscriptBox["\[ScriptCapitalN]", "2"], "-", 
           SubscriptBox["\[ScriptCapitalN]", "1"]}]]}]}], ")"}], 
      "\[CenterDot]", 
      FractionBox[
       SubscriptBox["\[ScriptCapitalN]", "365"], 
       SubscriptBox["\[ScriptCapitalN]", "30"]]}]]}]}], 
  TraditionalForm]], "DisplayFormulaNumbered",
 CellChangeTimes->{{3.4693769615910683`*^9, 3.4693769714040623`*^9}, {
  3.46937701479077*^9, 3.469377026858858*^9}, {3.469377068127583*^9, 
  3.4693770734121017`*^9}, {3.469377198497675*^9, 3.469377199195253*^9}, {
  3.46937729480742*^9, 3.469377309338704*^9}, {3.469377464630556*^9, 
  3.469377474029212*^9}},
 TextAlignment->Center,
 TextJustification->0.,
 CellTags->"eqn3"],

Cell[TextData[{
 "The CBOE\[RegisteredTrademark] whitepaper calculates number of minutes \
until settlement ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["N", "i"], TraditionalForm]]],
 ", below we use number of seconds. The values for the number of seconds to \
settlement at 8:30am on settlement day are given below. Note that ",
 StyleBox["N", "MB"],
 " is a protected ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function to convert integers to reals. Below we use \[ScriptCapitalN]."
}], "Text",
 CellChangeTimes->{{3.469377517419742*^9, 3.469377643095159*^9}, {
  3.4694546782301702`*^9, 3.46945467975812*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"now", "=", 
   RowBox[{
    RowBox[{"DateList", "[", "]"}], "/.", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x_", ",", "y_", ",", "z_", ",", "__"}], "}"}], "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"x", ",", "y", ",", "z", ",", "8", ",", "30", ",", "0."}], 
      "}"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nearTerm", "=", 
   RowBox[{
    RowBox[{"DatePlus", "[", 
     RowBox[{"now", ",", "9"}], "]"}], "/.", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x_", ",", "y_", ",", "z_", ",", "__"}], "}"}], "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"x", ",", "y", ",", "z", ",", "8", ",", "30", ",", "0."}], 
      "}"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nextTerm", "=", 
   RowBox[{
    RowBox[{"DatePlus", "[", 
     RowBox[{"now", ",", "37"}], "]"}], "/.", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x_", ",", "y_", ",", "z_", ",", "__"}], "}"}], "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"x", ",", "y", ",", "z", ",", "8", ",", "30", ",", "0."}], 
      "}"}]}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   SubscriptBox["\[ScriptCapitalN]", "1"], "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"AbsoluteTime", "[", "nearTerm", "]"}], "-", 
     RowBox[{"AbsoluteTime", "[", "now", "]"}]}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["\[ScriptCapitalN]", "2"], "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"AbsoluteTime", "[", "nextTerm", "]"}], "-", 
     RowBox[{"AbsoluteTime", "[", "now", "]"}]}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"secondPer30Days", "=", 
   RowBox[{"N", "[", 
    RowBox[{"30", "*", "24", "*", "60", "*", "60"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["\[ScriptCapitalN]", "30"], "=", "secondPer30Days"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["\[ScriptCapitalN]", "365"], "=", "secondsPerYear"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.469375791738885*^9, 3.46937579496099*^9}, 
   3.4693758252448683`*^9, {3.469377665805764*^9, 3.469377679943573*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"\[Sigma]1", "=", 
  RowBox[{"processOptionData2", "[", 
   RowBox[{"near", ",", "0.0038", ",", "9"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"\[Sigma]2", "=", 
  RowBox[{"processOptionData2", "[", 
   RowBox[{"next", ",", "0.0038", ",", "37"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.4693758639619923`*^9, 3.469375867354246*^9}, {
  3.469377094571534*^9, 3.469377097627277*^9}}],

Cell[BoxData["0.47276722522261405`"], "Output",
 CellChangeTimes->{3.469455098180252*^9, 3.4695365019788303`*^9, 
  3.469536550020536*^9, 3.470139175104125*^9}],

Cell[BoxData["0.36681815471859974`"], "Output",
 CellChangeTimes->{3.469455098180252*^9, 3.4695365019788303`*^9, 
  3.469536550020536*^9, 3.470139175106518*^9}]
}, Open  ]],

Cell["\<\
The VIX\[RegisteredTrademark] calculation is straightforward:\
\>", "Text",
 CellChangeTimes->{{3.469377689615671*^9, 3.469377700542387*^9}, 
   3.4694547274240503`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"100.", "*", 
  RowBox[{"Sqrt", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[ScriptCapitalT]", "1"], "*", "\[Sigma]1", "*", 
       FractionBox[
        RowBox[{
         SubscriptBox["\[ScriptCapitalN]", "2"], "-", 
         SubscriptBox["\[ScriptCapitalN]", "30"]}], 
        RowBox[{
         SubscriptBox["\[ScriptCapitalN]", "2"], "-", 
         SubscriptBox["\[ScriptCapitalN]", "1"]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[ScriptCapitalT]", "2"], "*", "\[Sigma]2", "*", 
       FractionBox[
        RowBox[{
         SubscriptBox["\[ScriptCapitalN]", "30"], "-", 
         SubscriptBox["\[ScriptCapitalN]", "1"]}], 
        RowBox[{
         SubscriptBox["\[ScriptCapitalN]", "2"], "-", 
         SubscriptBox["\[ScriptCapitalN]", "1"]}]]}]}], ")"}], "*", 
    FractionBox[
     SubscriptBox["\[ScriptCapitalN]", "365"], 
     SubscriptBox["\[ScriptCapitalN]", "30"]]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4692961637990427`*^9, 3.469296218186623*^9}, {
  3.469296286093845*^9, 3.469296365014282*^9}, {3.469377099742173*^9, 
  3.469377106142187*^9}}],

Cell[BoxData["61.21799857937212`"], "Output",
 CellChangeTimes->{3.469455098214328*^9, 3.469536502714669*^9, 
  3.469536550076561*^9, 3.4701391751593*^9}]
}, Open  ]],

Cell["Note that in the VIX formula", "Text",
 CellChangeTimes->{{3.469377144219802*^9, 3.469377145818076*^9}, {
  3.469377718657422*^9, 3.469377722230949*^9}}],

Cell[TextData[Cell[BoxData[
 FormBox[
  SqrtBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[ScriptCapitalT]", "1"], "\[CenterDot]", 
       SubsuperscriptBox["\[Sigma]", "1", "2"], "\[CenterDot]", 
       FractionBox[
        RowBox[{
         SubscriptBox["\[ScriptCapitalN]", "2"], "-", 
         SubscriptBox["\[ScriptCapitalN]", "30"]}], 
        RowBox[{
         SubscriptBox["\[ScriptCapitalN]", "2"], "-", 
         SubscriptBox["\[ScriptCapitalN]", "1"]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[ScriptCapitalT]", "2"], "\[CenterDot]", 
       SubsuperscriptBox["\[Sigma]", "2", "2"], "\[CenterDot]", 
       FractionBox[
        RowBox[{
         SubscriptBox["\[ScriptCapitalN]", "30"], "-", 
         SubscriptBox["\[ScriptCapitalN]", "1"]}], 
        RowBox[{
         SubscriptBox["\[ScriptCapitalN]", "2"], "-", 
         SubscriptBox["\[ScriptCapitalN]", "1"]}]]}]}], ")"}], "\[CenterDot]", 
    FractionBox[
     SubscriptBox["\[ScriptCapitalN]", "365"], 
     SubscriptBox["\[ScriptCapitalN]", "30"]]}]], 
  TraditionalForm]]]], "DisplayFormula",
 CellChangeTimes->{{3.4693769615910683`*^9, 3.4693769714040623`*^9}, {
  3.46937701479077*^9, 3.469377026858858*^9}, {3.469377068127583*^9, 
  3.4693770734121017`*^9}, {3.469377198497675*^9, 3.469377199195253*^9}, {
  3.46937729480742*^9, 3.469377309338704*^9}},
 TextAlignment->Center,
 TextJustification->0.],

Cell["is equivalent to", "Text",
 CellChangeTimes->{{3.469377150466345*^9, 3.4693771539542933`*^9}}],

Cell[TextData[Cell[BoxData[
 FormBox[
  SqrtBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FractionBox[
        SubscriptBox["\[ScriptCapitalN]", "1"], 
        SubscriptBox["\[ScriptCapitalN]", "365"]], "\[CenterDot]", 
       SubsuperscriptBox["\[Sigma]", "1", "2"], "\[CenterDot]", 
       FractionBox[
        RowBox[{
         SubscriptBox["\[ScriptCapitalN]", "2"], "-", 
         SubscriptBox["\[ScriptCapitalN]", "30"]}], 
        RowBox[{
         SubscriptBox["\[ScriptCapitalN]", "2"], "-", 
         SubscriptBox["\[ScriptCapitalN]", "1"]}]]}], "+", 
      RowBox[{
       FractionBox[
        SubscriptBox["\[ScriptCapitalN]", "2"], 
        SubscriptBox["\[ScriptCapitalN]", "365"]], "\[CenterDot]", 
       SubsuperscriptBox["\[Sigma]", "2", "2"], "\[CenterDot]", 
       FractionBox[
        RowBox[{
         SubscriptBox["\[ScriptCapitalN]", "30"], "-", 
         SubscriptBox["\[ScriptCapitalN]", "1"]}], 
        RowBox[{
         SubscriptBox["\[ScriptCapitalN]", "2"], "-", 
         SubscriptBox["\[ScriptCapitalN]", "1"]}]]}]}], ")"}], "\[CenterDot]", 
    FractionBox[
     SubscriptBox["\[ScriptCapitalN]", "365"], 
     SubscriptBox["\[ScriptCapitalN]", "30"]]}]], 
  TraditionalForm]]]], "DisplayFormula",
 CellChangeTimes->{{3.4693769615910683`*^9, 3.4693769714040623`*^9}, 
   3.469377009605608*^9, {3.4693771158810253`*^9, 3.4693771375195513`*^9}, {
   3.46937726059317*^9, 3.469377290809215*^9}},
 TextAlignment->Center,
 TextJustification->0.],

Cell["which reduces to", "Text",
 CellChangeTimes->{{3.46937718371527*^9, 3.4693771861870604`*^9}, 
   3.46937731480869*^9}],

Cell[TextData[Cell[BoxData[
 FormBox[
  SqrtBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[ScriptCapitalN]", "1"], "\[CenterDot]", 
       SubsuperscriptBox["\[Sigma]", "1", "2"], "\[CenterDot]", 
       FractionBox[
        RowBox[{
         SubscriptBox["\[ScriptCapitalN]", "2"], "-", 
         SubscriptBox["\[ScriptCapitalN]", "30"]}], 
        RowBox[{
         SubscriptBox["\[ScriptCapitalN]", "2"], "-", 
         SubscriptBox["\[ScriptCapitalN]", "1"]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[ScriptCapitalN]", "2"], "\[CenterDot]", 
       SubsuperscriptBox["\[Sigma]", "2", "2"], "\[CenterDot]", 
       FractionBox[
        RowBox[{
         SubscriptBox["\[ScriptCapitalN]", "30"], "-", 
         SubscriptBox["\[ScriptCapitalN]", "1"]}], 
        RowBox[{
         SubscriptBox["\[ScriptCapitalN]", "2"], "-", 
         SubscriptBox["\[ScriptCapitalN]", "1"]}]]}]}], ")"}], "\[CenterDot]", 
    FractionBox["1", 
     SubscriptBox["\[ScriptCapitalN]", "30"]]}]], 
  TraditionalForm]]]], "DisplayFormula",
 CellChangeTimes->{{3.4693769615910683`*^9, 3.4693769714040623`*^9}, 
   3.469377009605608*^9, {3.4693771158810253`*^9, 3.4693771375195513`*^9}, {
   3.46937726059317*^9, 3.469377290809215*^9}, {3.469377325170093*^9, 
   3.469377333416202*^9}},
 TextAlignment->Center,
 TextJustification->0.],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", "VIX", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"VIX", "[", 
   RowBox[{
   "nearData_", ",", "nextData_", ",", "nearDays_", ",", "nextDays_", ",", 
    "rate_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "now", ",", "nearTerm", ",", "nextTerm", ",", "\[ScriptCapitalN]1", ",", 
      "\[ScriptCapitalN]2", ",", "\[ScriptCapitalN]30", ",", 
      "\[ScriptCapitalN]365", ",", "\[Sigma]1", ",", "\[Sigma]2"}], "}"}], 
    ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{"create", " ", "the", " ", "time", " ", "constants"}], " ", 
     "*)"}], "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{
      RowBox[{
      "assuming", " ", "that", " ", "you", " ", "want", " ", "to", " ", "set",
        " ", "the", " ", "current", " ", "day", " ", "time", " ", "to", " ", 
       "8"}], ":", 
      RowBox[{"30", "am"}]}], " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"now", "=", 
      RowBox[{
       RowBox[{"DateList", "[", "]"}], "/.", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"x_", ",", "y_", ",", "z_", ",", "__"}], "}"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"x", ",", "y", ",", "z", ",", "8", ",", "30", ",", "0."}], 
         "}"}]}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"nearTerm", "=", 
      RowBox[{
       RowBox[{"DatePlus", "[", 
        RowBox[{"now", ",", "nearDays"}], "]"}], "/.", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"x_", ",", "y_", ",", "z_", ",", "__"}], "}"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"x", ",", "y", ",", "z", ",", "8", ",", "30", ",", "0."}], 
         "}"}]}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"nextTerm", "=", 
      RowBox[{
       RowBox[{"DatePlus", "[", 
        RowBox[{"now", ",", "nextDays"}], "]"}], "/.", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"x_", ",", "y_", ",", "z_", ",", "__"}], "}"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"x", ",", "y", ",", "z", ",", "8", ",", "30", ",", "0."}], 
         "}"}]}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"\[ScriptCapitalN]1", "=", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"AbsoluteTime", "[", "nearTerm", "]"}], "-", 
        RowBox[{"AbsoluteTime", "[", "now", "]"}]}], ")"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"\[ScriptCapitalN]2", "=", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"AbsoluteTime", "[", "nextTerm", "]"}], "-", 
        RowBox[{"AbsoluteTime", "[", "now", "]"}]}], ")"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"\[ScriptCapitalN]30", "=", 
      RowBox[{"N", "[", 
       RowBox[{"30", "*", "24", "*", "60", "*", "60"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"\[ScriptCapitalN]365", "=", 
      RowBox[{"N", "[", 
       RowBox[{"365", "*", "24", "*", "60", "*", "60"}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"calculation", " ", "of", " ", 
       SuperscriptBox["\[Sigma]", "2"]}], " ", "*)"}], "\[IndentingNewLine]", 
     
     RowBox[{"\[Sigma]1", "=", 
      RowBox[{"processOptionData2", "[", 
       RowBox[{"nearData", ",", "rate", ",", "nearDays"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"\[Sigma]2", "=", 
      RowBox[{"processOptionData2", "[", 
       RowBox[{"nextData", ",", "rate", ",", "nextDays"}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"calculation", " ", "of", " ", "VIX"}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"100.", "*", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["\[ScriptCapitalN]1", "\[ScriptCapitalN]365"], "*", 
           "\[Sigma]1", "*", 
           FractionBox[
            RowBox[{"\[ScriptCapitalN]2", "-", "\[ScriptCapitalN]30"}], 
            RowBox[{"\[ScriptCapitalN]2", "-", "\[ScriptCapitalN]1"}]]}], "+", 
          RowBox[{
           FractionBox["\[ScriptCapitalN]2", "\[ScriptCapitalN]365"], "*", 
           "\[Sigma]2", "*", 
           FractionBox[
            RowBox[{"\[ScriptCapitalN]30", "-", "\[ScriptCapitalN]1"}], 
            RowBox[{"\[ScriptCapitalN]2", "-", "\[ScriptCapitalN]1"}]]}]}], 
         ")"}], "*", 
        FractionBox["\[ScriptCapitalN]365", "\[ScriptCapitalN]30"]}], 
       "]"}]}]}]}], "\[IndentingNewLine]", "]"}]}]}], "Input",
 CellChangeTimes->{{3.4693749976637983`*^9, 3.469374999019843*^9}, {
   3.469375126640017*^9, 3.469375415470129*^9}, {3.4693755311094437`*^9, 
   3.469375550971369*^9}, 3.4693755950306253`*^9, {3.469375661598753*^9, 
   3.4693756656392*^9}, {3.469375719566863*^9, 3.469375730302299*^9}, {
   3.469375900904044*^9, 3.469375912344802*^9}, {3.469375947555643*^9, 
   3.469376039063891*^9}, {3.4693760827784348`*^9, 3.4693760947328777`*^9}, {
   3.469376696612728*^9, 3.469376862754558*^9}, {3.469377735897246*^9, 
   3.469377737781478*^9}, {3.469379688536099*^9, 3.469379759405064*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"VIX", "[", 
  RowBox[{"near", ",", "next", ",", "9", ",", "37", ",", "0.0038"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.4693755583204727`*^9, 3.469375570632739*^9}}],

Cell[BoxData["61.21799857937212`"], "Output",
 CellChangeTimes->{3.469455098280553*^9, 3.469536503530322*^9, 
  3.4695365501699553`*^9, 3.4701391752531843`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->None,
WindowToolbars->"EditBar",
WindowSize->{985, 914},
WindowMargins->{{42, Automatic}, {Automatic, 0}},
ShowSelection->True,
Magnification:>FEPrivate`If[
  FEPrivate`Equal[FEPrivate`$VersionNumber, 6.], 1.25, 1.25 Inherited],
FrontEndVersion->"7.0 for Mac OS X x86 (32-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "eqn1"->{
  Cell[3035, 79, 1048, 33, 57, "DisplayFormulaNumbered",
   CellTags->"eqn1"]},
 "eqn2"->{
  Cell[5111, 143, 461, 15, 47, "DisplayFormulaNumbered",
   CellTags->"eqn2"]},
 "eqn3"->{
  Cell[226533, 6269, 1605, 40, 72, "DisplayFormulaNumbered",
   CellTags->"eqn3"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"eqn1", 243917, 6735},
 {"eqn2", 244008, 6738},
 {"eqn3", 244099, 6741}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 142, 3, 95, "Title"],
Cell[CellGroupData[{
Cell[734, 29, 124, 2, 33, "Input"],
Cell[861, 33, 101, 1, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[999, 39, 99, 1, 83, "Section"],
Cell[1101, 42, 1581, 27, 145, "Text"],
Cell[2685, 71, 347, 6, 32, "Text"],
Cell[3035, 79, 1048, 33, 57, "DisplayFormulaNumbered",
 CellTags->"eqn1"],
Cell[4086, 114, 1022, 27, 107, "Text"],
Cell[5111, 143, 461, 15, 47, "DisplayFormulaNumbered",
 CellTags->"eqn2"],
Cell[5575, 160, 458, 13, 70, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6070, 178, 107, 1, 83, "Section"],
Cell[6180, 181, 482, 10, 51, "Text"],
Cell[6665, 193, 340, 9, 51, "Text"],
Cell[CellGroupData[{
Cell[7030, 206, 224, 4, 33, "Input"],
Cell[7257, 212, 262, 6, 33, "Output"]
}, Open  ]],
Cell[7534, 221, 475, 12, 51, "Text"],
Cell[CellGroupData[{
Cell[8034, 237, 347, 9, 33, "Input"],
Cell[8384, 248, 235, 5, 33, "Output"]
}, Open  ]],
Cell[8634, 256, 272, 5, 32, "Text"],
Cell[CellGroupData[{
Cell[8931, 265, 308, 7, 53, "Input"],
Cell[9242, 274, 237, 5, 33, "Output"],
Cell[9482, 281, 236, 5, 33, "Output"]
}, Open  ]],
Cell[9733, 289, 335, 6, 32, "Text"],
Cell[CellGroupData[{
Cell[10093, 299, 333, 6, 33, "Input"],
Cell[10429, 307, 149, 2, 37, "Output"]
}, Open  ]],
Cell[10593, 312, 899, 21, 32, "Text"],
Cell[CellGroupData[{
Cell[11517, 337, 517, 12, 33, "Input"],
Cell[12037, 351, 165, 2, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12239, 358, 388, 10, 33, "Input"],
Cell[12630, 370, 158, 2, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12825, 377, 104, 1, 42, "Subsection"],
Cell[12932, 380, 888, 23, 70, "Text"],
Cell[CellGroupData[{
Cell[13845, 407, 278, 6, 35, "Input"],
Cell[14126, 415, 147, 2, 33, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[14334, 424, 181, 4, 83, "Section"],
Cell[14518, 430, 171, 2, 32, "Text"],
Cell[14692, 434, 626, 17, 53, "Input"],
Cell[15321, 453, 338, 8, 51, "Text"],
Cell[15662, 463, 1226, 31, 107, "Text"],
Cell[CellGroupData[{
Cell[16913, 498, 872, 21, 33, "Input"],
Cell[17788, 521, 581, 17, 33, "Output"]
}, Open  ]],
Cell[18384, 541, 216, 6, 32, "Text"],
Cell[18603, 549, 349, 13, 33, "Input",
 Evaluatable->False],
Cell[18955, 564, 174, 5, 32, "Text"],
Cell[CellGroupData[{
Cell[19154, 573, 247, 4, 33, "Input"],
Cell[19404, 579, 13981, 394, 661, "Output"]
}, Open  ]],
Cell[33400, 976, 362, 7, 51, "Text"],
Cell[CellGroupData[{
Cell[33787, 987, 621, 17, 33, "Input"],
Cell[34411, 1006, 13983, 394, 661, "Output"]
}, Open  ]],
Cell[48409, 1403, 117, 1, 32, "Text"],
Cell[CellGroupData[{
Cell[48551, 1408, 471, 15, 33, "Input"],
Cell[49025, 1425, 12430, 350, 585, "Output"]
}, Open  ]],
Cell[61470, 1778, 521, 10, 70, "Text"],
Cell[CellGroupData[{
Cell[62016, 1792, 834, 22, 53, "Input"],
Cell[62853, 1816, 215, 5, 33, "Output"],
Cell[63071, 1823, 214, 5, 33, "Output"]
}, Open  ]],
Cell[63300, 1831, 181, 4, 32, "Text"],
Cell[CellGroupData[{
Cell[63506, 1839, 917, 23, 53, "Input"],
Cell[64426, 1864, 190, 4, 33, "Output"],
Cell[64619, 1870, 189, 4, 33, "Output"]
}, Open  ]],
Cell[64823, 1877, 193, 2, 32, "Text"],
Cell[CellGroupData[{
Cell[65041, 1883, 1070, 28, 55, "Input"],
Cell[66114, 1913, 156, 2, 33, "Output"],
Cell[66273, 1917, 158, 2, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[66468, 1924, 108, 1, 42, "Subsection"],
Cell[66579, 1927, 661, 20, 32, "Text"],
Cell[67243, 1949, 200, 5, 32, "Text"],
Cell[CellGroupData[{
Cell[67468, 1958, 405, 9, 33, "Input"],
Cell[67876, 1969, 1191, 18, 110, "Output"]
}, Open  ]],
Cell[69082, 1990, 174, 4, 32, "Text"],
Cell[CellGroupData[{
Cell[69281, 1998, 563, 14, 33, "Input"],
Cell[69847, 2014, 139, 2, 33, "Output"]
}, Open  ]],
Cell[70001, 2019, 1013, 34, 70, "Text"],
Cell[CellGroupData[{
Cell[71039, 2057, 408, 11, 33, "Input"],
Cell[71450, 2070, 6388, 164, 319, "Output"]
}, Open  ]],
Cell[77853, 2237, 198, 5, 32, "Text"],
Cell[CellGroupData[{
Cell[78076, 2246, 829, 19, 33, "Input"],
Cell[78908, 2267, 6408, 164, 319, "Output"]
}, Open  ]],
Cell[85331, 2434, 365, 9, 32, "Text"],
Cell[85699, 2445, 779, 17, 70, "Text"],
Cell[CellGroupData[{
Cell[86503, 2466, 687, 16, 33, "Input"],
Cell[87193, 2484, 6080, 156, 300, "Output"]
}, Open  ]],
Cell[93288, 2643, 455, 14, 32, "Text"],
Cell[93746, 2659, 130, 1, 32, "Text"],
Cell[CellGroupData[{
Cell[93901, 2664, 561, 15, 33, "Input"],
Cell[94465, 2681, 9045, 232, 452, "Output"]
}, Open  ]],
Cell[103525, 2916, 385, 8, 32, "Text"],
Cell[CellGroupData[{
Cell[103935, 2928, 709, 16, 33, "Input"],
Cell[104647, 2946, 4886, 124, 262, "Output"]
}, Open  ]],
Cell[109548, 3073, 848, 25, 32, "Text"],
Cell[110399, 3100, 409, 11, 32, "Text"],
Cell[CellGroupData[{
Cell[110833, 3115, 253, 7, 33, "Input"],
Cell[111089, 3124, 262, 6, 33, "Output"]
}, Open  ]],
Cell[111366, 3133, 649, 19, 32, "Text"],
Cell[CellGroupData[{
Cell[112040, 3156, 1188, 28, 33, "Input"],
Cell[113231, 3186, 262, 6, 33, "Output"]
}, Open  ]],
Cell[113508, 3195, 183, 5, 32, "Text"],
Cell[CellGroupData[{
Cell[113716, 3204, 851, 23, 33, "Input"],
Cell[114570, 3229, 262, 6, 33, "Output"]
}, Open  ]],
Cell[114847, 3238, 223, 5, 32, "Text"],
Cell[CellGroupData[{
Cell[115095, 3247, 473, 10, 33, "Input"],
Cell[115571, 3259, 10836, 277, 547, "Output"]
}, Open  ]],
Cell[126422, 3539, 130, 1, 32, "Text"],
Cell[CellGroupData[{
Cell[126577, 3544, 482, 12, 33, "Input"],
Cell[127062, 3558, 9305, 276, 414, "Output"]
}, Open  ]],
Cell[136382, 3837, 338, 7, 32, "Text"],
Cell[136723, 3846, 5595, 152, 395, "Input"],
Cell[CellGroupData[{
Cell[142343, 4002, 245, 5, 33, "Input"],
Cell[142591, 4009, 9305, 276, 414, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[151933, 4290, 218, 4, 33, "Input"],
Cell[152154, 4296, 7610, 224, 338, "Output"]
}, Open  ]],
Cell[159779, 4523, 305, 6, 32, "Text"],
Cell[160087, 4531, 6498, 171, 433, "Input"],
Cell[CellGroupData[{
Cell[166610, 4706, 370, 6, 33, "Input"],
Cell[166983, 4714, 9304, 276, 414, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[176324, 4995, 268, 5, 33, "Input"],
Cell[176595, 5002, 7610, 224, 338, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[184266, 5233, 190, 4, 83, "Section"],
Cell[184459, 5239, 1132, 36, 51, "Text"],
Cell[185594, 5277, 380, 11, 32, "Text"],
Cell[CellGroupData[{
Cell[185999, 5292, 677, 20, 56, "Input"],
Cell[186679, 5314, 1227, 46, 50, "Output"]
}, Open  ]],
Cell[187921, 5363, 397, 8, 51, "Text"],
Cell[CellGroupData[{
Cell[188343, 5375, 228, 4, 33, "Input"],
Cell[188574, 5381, 1935, 28, 167, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[190546, 5414, 326, 8, 33, "Input"],
Cell[190875, 5424, 1890, 27, 129, "Output"]
}, Open  ]],
Cell[192780, 5454, 436, 9, 51, "Text"],
Cell[CellGroupData[{
Cell[193241, 5467, 1489, 37, 53, "Input"],
Cell[194733, 5506, 1917, 28, 129, "Output"]
}, Open  ]],
Cell[196665, 5537, 455, 13, 54, "Text"],
Cell[CellGroupData[{
Cell[197145, 5554, 381, 7, 41, "Input"],
Cell[197529, 5563, 4704, 73, 523, "Output"]
}, Open  ]],
Cell[202248, 5639, 993, 28, 95, "Text"],
Cell[CellGroupData[{
Cell[203266, 5671, 786, 16, 42, "Input"],
Cell[204055, 5689, 4679, 72, 506, "Output"]
}, Open  ]],
Cell[208749, 5764, 495, 13, 36, "Text"],
Cell[209247, 5779, 1051, 33, 68, "Text"],
Cell[CellGroupData[{
Cell[210323, 5816, 422, 10, 59, "Input"],
Cell[210748, 5828, 159, 2, 33, "Output"]
}, Open  ]],
Cell[210922, 5833, 340, 8, 51, "Text"],
Cell[211265, 5843, 349, 12, 51, "DisplayFormula"],
Cell[CellGroupData[{
Cell[211639, 5859, 884, 23, 62, "Input"],
Cell[212526, 5884, 160, 2, 33, "Output"]
}, Open  ]],
Cell[212701, 5889, 196, 3, 32, "Text"],
Cell[212900, 5894, 2195, 64, 130, "Input",
 Evaluatable->False],
Cell[215098, 5960, 199, 2, 32, "Text"],
Cell[215300, 5964, 8560, 225, 576, "Input"],
Cell[223863, 6191, 1266, 37, 76, "Text"],
Cell[225132, 6230, 266, 7, 33, "Input",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[225423, 6241, 345, 6, 53, "Input"],
Cell[225771, 6249, 160, 2, 33, "Output"],
Cell[225934, 6253, 160, 2, 33, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[226143, 6261, 202, 2, 83, "Section"],
Cell[226348, 6265, 182, 2, 32, "Text"],
Cell[226533, 6269, 1605, 40, 72, "DisplayFormulaNumbered",
 CellTags->"eqn3"],
Cell[228141, 6311, 625, 15, 70, "Text"],
Cell[228769, 6328, 2128, 63, 167, "Input"],
Cell[CellGroupData[{
Cell[230922, 6395, 413, 9, 53, "Input"],
Cell[231338, 6406, 160, 2, 33, "Output"],
Cell[231501, 6410, 160, 2, 33, "Output"]
}, Open  ]],
Cell[231676, 6415, 179, 4, 32, "Text"],
Cell[CellGroupData[{
Cell[231880, 6423, 1138, 29, 59, "Input"],
Cell[233021, 6454, 154, 2, 33, "Output"]
}, Open  ]],
Cell[233190, 6459, 159, 2, 32, "Text"],
Cell[233352, 6463, 1422, 35, 57, "DisplayFormula"],
Cell[234777, 6500, 100, 1, 32, "Text"],
Cell[234880, 6503, 1500, 38, 57, "DisplayFormula"],
Cell[236383, 6543, 124, 2, 32, "Text"],
Cell[236510, 6547, 1361, 34, 57, "DisplayFormula"],
Cell[237874, 6583, 5161, 120, 491, "Input"],
Cell[CellGroupData[{
Cell[243060, 6707, 192, 4, 33, "Input"],
Cell[243255, 6713, 160, 2, 33, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
